import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Warning: could not send message for past 8 hours',
    from_='MAILER-DAEMON@tppppp.com.au',
    to=('jennifer@sss.sssssss.net.au',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(2008, 1, 17, 3, 40, 52, tzinfo=datetime.timezone(datetime.timedelta(seconds=39600))),
    date_str='Thu, 17 Jan 2008 03:40:52 +1100',
    text='    **********************************************\r\n    **      THIS IS A WARNING MESSAGE ONLY      **\r\n    **  YOU DO NOT NEED TO RESEND YOUR MESSAGE  **\r\n    **********************************************\r\n\r\nThe original message was received at Wed, 16 Jan 2008 19:38:07 +1100\r\nfrom 60-0-0-61.static.tppppp.com.au [60.0.0.61]\r\n\r\nThis message was generated by mail11.tppppp.com.au\r\n\r\n   ----- Transcript of session follows -----\r\n.... while talking to mail.oooooooo.com.au.:\r\n>>> DATA\r\n<<< 452 4.2.2 <fraser@oooooooo.com.au>... Mailbox full\r\n<fraser@oooooooo.com.au>... Deferred: 452 4.2.2 <fraser@oooooooo.com.au>... Mailbox full\r\n<<< 503 5.0.0 Need RCPT (recipient)\r\nWarning: message still undelivered after 8 hours\r\nWill keep trying until message is 5 days old\r\n\r\n-- \r\nThis message has been scanned for viruses and\r\ndangerous content by MailScanner, and is\r\nbelieved to be clean.\r\n\r\n',
    html='',
    headers={'return-path': ('<mail_dump@ns1.sssssss.net.au>',), 'received': ('from acomputer ([unix socket])\r\n\t by imap01.sssssss.net (Cyrus) with LMTPA;\r\n\t Wed, 16 Jan 2008 13:51:42 -0800', 'from smtp.sssssss.org (unknown [198.0.0.92])\r\n\tby imap01.sssssss.net (Postfix) with ESMTP id BFE6477FAE\r\n\tfor <aaaa@sssssss.net>; Wed, 16 Jan 2008 13:51:40 -0800 (PST)', 'from ns1.sssssss.net.au (ns1.sssssss.net.au [202.0.0.246])\r\n\tby smtp.sssssss.org (Postfix) with ESMTP id 96E5C6C6830\r\n\tfor <aaaa@sssssss.net>; Wed, 16 Jan 2008 11:08:14 -0800 (PST)', 'from ns1.sssssss.net.au (unknown [127.0.0.1])\r\n\tby ns1.sssssss.net.au (Postfix) with ESMTP id E1BCEF227\r\n\tfor <aaaa@sssssss.net>; Thu, 17 Jan 2008 03:40:53 +1100 (EST)', 'from ns1.sssssss.net.au (ns1.sssssss.net.au [202.0.0.246])\r\n        by localhost (FormatMessage) with SMTP id ceaa681bbcb6c7f6\r\n        for <jennifer@sss.sssssss.net.au>; Thu, 17 Jan 2008 03:40:53 +1100 (EST)', 'from mail11.tppppp.com.au (unknown [203.0.0.161])\r\n\tby ns1.sssssss.net.au (Postfix) with ESMTP id 7F2D2F225\r\n\tfor <jennifer@sss.sssssss.net.au>; Thu, 17 Jan 2008 03:40:52 +1100 (EST)', 'from localhost (localhost)\r\n\tby mail11.tppppp.com.au (envelope-from MAILER-DAEMON) (8.14.2/8.14.2) id m0GFZ1c3009410;\r\n\tThu, 17 Jan 2008 03:40:52 +1100'), 'x-sieve': ('CMU Sieve 2.2',), 'date': ('Thu, 17 Jan 2008 03:40:52 +1100',), 'from': ('Mail Delivery Subsystem <MAILER-DAEMON@tppppp.com.au>',), 'message-id': ('<200801161640.m0GFZ1c3009410@mail11.ttttt.com.au>',), 'to': ('<jennifer@sss.sssssss.net.au>',), 'mime-version': ('1.0',), 'content-type': ('multipart/report; report-type=delivery-status;\r\n\tboundary="m0GFZ1c3009410.1200501652/mail11.ttttt.com.au"',), 'subject': ('Warning: could not send message for past 8 hours',), 'auto-submitted': ('auto-generated (warning-timeout)',), 'resent-date': ('Thu, 17 Jan 2008 03:40:53 +1100 (EST)',), 'resent-from': ('<mail_dump@ns1.sssssss.net.au>',), 'resent-to': ('<mikel@sssssss.net>',), 'resent-message-id': ('<ceaa681bbcb6c7f6.1200501653@sssssss.net.au>',), 'x-spam-status': ('No',)},
    attachments=[],
    from_values=EmailAddress(name='Mail Delivery Subsystem', email='MAILER-DAEMON@tppppp.com.au'),
    to_values=(EmailAddress(name='', email='jennifer@sss.sssssss.net.au'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


"""
Email modification is not common case operation
Most likely it will not be added to lib

Also, I have tried to add public attribute - MailMessage.orig_bytes (raw_message_data)
But it have increased memory consumption: ~10%
"""

import email
from imap_tools import MailBox, A

with MailBox('imap.mail.com').login('test@mail.com', 'password') as mailbox:
    for msg in mailbox.fetch(A(subject='[some]')):
        altered_msg = email.message_from_bytes(msg.obj.as_bytes())
        altered_msg.replace_header('Subject', '[my own subject extension] ' + msg.subject)
        mailbox.append(altered_msg.as_bytes())



import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Re: Testing multipart/signed',
    from_='test@test.lindsaar.net',
    to=('mikel@test.lindsaar.net',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(2007, 6, 4, 15, 1, 31, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=61200))),
    date_str='Mon, 4 Jun 2007 15:01:31 -0700',
    text='This is random text, not what has been signed below, ie, this sig\r\nemail is not signed correctly.\r\n',
    html='',
    headers={'date': ('Mon, 4 Jun 2007 15:01:31 -0700',), 'from': ('Test <test@test.lindsaar.net>',), 'to': ('Mikel <mikel@test.lindsaar.net>',), 'subject': ('Re: Testing multipart/signed',), 'message-id': ('<20070604150131.40d4fa1e@reforged>',), 'mime-version': ('1.0',), 'content-type': ('multipart/signed; boundary=Sig_2GIY2xfzqSADMmu9sKGJqWm;\r\n protocol="application/pgp-signature"; micalg=PGP-SHA1',)},
    attachments=[
        dict(
            filename='signature.asc',
            content_id='',
            content_disposition='attachment',
            content_type='application/pgp-signature',
            payload=b'-----BEGIN PGP SIGNATURE-----\r\nVersion: GnuPG v1.4.6 (GNU/Linux)\r\n\r\niD8DB1111Iu7dfRchrkBInkRArniAKCue17JOxXBiAZHwLy3uFacU+pmhwCgwzhf\r\nV5YSPv2xmYOA6mJ6oVaasseQ=\r\n=T7p9\r\n-----END PGP SIGNATURE-----\r\n',
        ),
        ],
    from_values=EmailAddress(name='Test', email='test@test.lindsaar.net'),
    to_values=(EmailAddress(name='Mikel', email='mikel@test.lindsaar.net'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='',
    from_='',
    to=(),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(1900, 1, 1, 0, 0),
    date_str='',
    text='quite Delivered-To: xxx@xxx.xxx\r\nReceived: by xxx.xxx.xxx (Wostfix, from userid xxx)\r\n\t  id 0F87F333; Wed, 23 Feb 2005 16:16:17 -0600\r\nDate: Wed, 23 Feb 2005 18:20:17 -0400\r\nFrom: "xxx xxx" <xxx@xxx.xxx>\r\nMessage-ID: <4D6AA7EB.6490534@xxx.xxx>\r\nTo: xxx@xxx.com\r\nSubject: Stop adware/spyware once and for all. \r\nX-Scanned-By: MIMEDefang 2.11 (www dot roaringpenguin dot com slash mimedefang)\r\n\r\nYou are infected with: \r\nAd Ware and Spy Ware\r\n\r\nGet your free scan and removal download now, \r\nbefore it gets any worse. \r\n\r\nhttp://xxx.xxx.info?aid=3D13&?stat=3D4327kdzt\r\n\r\n\r\n\r\n\r\nno more? (you will still be infected) \r\nhttp://xxx.xxx.info/discon/?xxx@xxx.com\r\n',
    html='',
    headers={'received': ('from xxx.xxx.xxx ([xxx.xxx.xxx.xxx] verified)\r\n  by xxx.com (CommuniGate Pro SMTP 4.2.8)\r\n  with SMTP id 2532598 for xxx@xxx.com; Wed, 23 Feb 2005 17:51:49 -0500',), 'received-spf': ('softfail\r\n receiver=xxx.com; client-ip=xxx.xxx.xxx.xxx; envelope-from=xxx@xxx.xxx',)},
    attachments=[],
    from_values=None,
    to_values=(),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='[0]: XXXXXXX XXXXX XXXXX !',
    from_='yusuf75thu@auracom.net',
    to=('abcdefg@AAAAAAAAA.net',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(3609, 6, 30, 15, 33, 50, tzinfo=datetime.timezone(datetime.timedelta(seconds=21600))),
    date_str='Mon, 30 Jun 3609 15:33:50 +0600',
    text='\r\nFilter2: This message has been scanned for viruses and\r\ndangerous content by MailScanner, and is\r\nbelieved to be clean.\r\n\r\n',
    html='<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN">\r\n<HTML><HEAD>\r\n<META http-equiv=Content-Type content="text/html; charset=utf-8">\r\n<META content="MSHTML 6.00.2900.2180" name=GENERATOR>\r\n<STYLE></STYLE>\r\n</HEAD>\r\n<BODY bgColor=#ffffff>\r\n<br />This message has been scanned for viruses and\r\n<br />dangerous content by\r\n<a href="http://www.mailscanner.info/"><b>MailScanner</b></a>, and is\r\n<br />believed to be clean.\r\n</HTML>\r\n',
    headers={'return-path': ('<yusuf75thu@auracom.net>',), 'received': ('from murder ([unix socket])\r\n         by imap1.AAAAAAAAA.net (Cyrus v2.2.12-Invoca-RPM-2.2.12-6.fc4) with LMTPA;\r\n         Mon, 30 Jun 2008 02:34:00 -0700', 'from smtp2.BBBBBBBBBBB.org (unknown [10.254.15.30])\r\n        by imap1.AAAAAAAAA.net (Postfix) with ESMTP id 9444077D75\r\n        for <abcdefg@AAAAAAAAA.net>; Mon, 30 Jun 2008 02:34:00 -0700 (PDT)', 'from localhost (unknown [92.47.238.91])\r\n        by smtp2.BBBBBBBBBBB.org (Postfix) with ESMTP id 44D0110011\r\n        for <abcdefg@AAAAAAAAA.net>; Mon,  9 Jun 2008 12:24:02 -0700 (PDT)'), 'x-sieve': ('CMU Sieve 2.2',), 'message-id': ('<86a2019dbec6$caa86cc0$390b0485@auracom.net>',), 'from': ('"=?windows-1251?B?wPLo6u7iYQ==?=" <yusuf75thu@auracom.net>',), 'to': ('<abcdefg@AAAAAAAAA.net>',), 'subject': ('[0]: XXXXXXX XXXXX XXXXX !',), 'date': ('Mon, 30 Jun 3609 15:33:50 +0600',), 'mime-version': ('1.0',), 'content-type': ('multipart/alternative;\r\n                boundary=----=_NextPart_000_0023_08_E8CD50F3.4EF2F754',), 'x-priority': ('3',), 'x-msmail-priority': ('Normal',), 'x-mailer': ('Microsoft Outlook Express 6.00.2900.2180',), 'x-mimeole': ('Produced By Microsoft MimeOLE V6.00.2900.2180',), 'x-csi-mailscanner-information': ('Please contact the ISP for more information',), 'x-csi-mailscanner': ('Found to be clean',), 'x-csi-mailscanner-spamcheck': ('spam, ORDB-RBL',), 'x-csi-mailscanner-from': ('yusuf75thu@auracom.net',), 'x-spam-status': ('Yes',)},
    attachments=[],
    from_values=EmailAddress(name='Атиковa', email='yusuf75thu@auracom.net'),
    to_values=(EmailAddress(name='', email='abcdefg@AAAAAAAAA.net'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Contact email-test.fr',
    from_='ne-pas-repondre@email-test.fr',
    to=('service.courrier@mairie-email-test.fr',),
    cc=(),
    bcc=(),
    reply_to=('emmanuellehelou@orange.fr',),
    date=datetime.datetime(2021, 1, 17, 16, 26, 56, tzinfo=datetime.timezone.utc),
    date_str='Sun, 17 Jan 2021 16:26:56 +0000',
    text="Bonjour.\n\nUne nouvelle demande vous a été transmise via le formulaire de contact du site www.saintnazaire.fr\n\nVotre message : onjour,\n\nJe voulais vous alerter que le pizzaïolo du camion ambulant PASTA PIZZA de Villès Martin du dimanche ne porte pas de masques pour confectionner ses pizzas et pour parler à ses clients; pas de gel hydroalcooloique non plus; travaillant dans les hôpitaux je suis consternée de voir encore des professionnels et en contact avec un public de ne pas respecter le port du masque; il contamine ses produits, les clients ...\nCe n'est pas normal de ne pas contrôler ces professionnels ambulants.\n\nMerci beaucoup\n\n\n\nMerci.\n",
    html='',
    headers={'from': ('email-test.fr <ne-pas-repondre@email-test.fr>',), 'to': ('Courrier <service.courrier@mairie-email-test.fr>',), 'subject': ('Contact email-test.fr',), 'thread-topic': ('Contact email-test.fr',), 'thread-index': ('AQHW7O2SJAZxCkqG10awu/NtCY1I/A==',), 'date': ('Sun, 17 Jan 2021 16:26:56 +0000',), 'message-id': ('<c831ea72834dd8fcc648dac294e810fb@www.email-test.fr>',), 'reply-to': ('HELOU <emmanuellehelou@orange.fr>',), 'content-language': ('fr-FR',), 'x-ms-exchange-organization-authas': ('Anonymous',), 'x-ms-exchange-organization-authsource': ('serv-exchange.mairie-email-test.fr',), 'x-ms-has-attach': ('',), 'x-ms-exchange-organization-network-message-id': ('b33ffe95-382f-49d7-269d-08d8bb04b512',), 'x-ms-tnef-correlator': ('',), 'x-ms-exchange-organization-recordreviewcfmtype': ('0',), 'x-ms-exchange-organization-originalclientipaddress': ('192.168.2.8',), 'x-ms-exchange-organization-originalserveripaddress': ('172.16.0.199',), 'x-mailer': ('TYPO3',), 'dkim-signature': ('v=1; a=rsa-sha256; c=simple/simple; d=email-test.fr;\ts=dkim;\r\n t=1610900816;\tbh=OW4RY4SudtC3hIBJtmsQXcuoAP02QMZsI0y7sCUVX00=;\r\n\th=Date:Subject:From:Reply-To:To:From;\r\n\tb=sPHozdsx6imqijuc+XCa9szrzsigwwFKERJ1KeO0L6Omm0gL+a4+F2/I3BePWKn5Y\r\n\t Y9Kott89Zop2kx/mnnGObQ9wY7RevYce9Ke5YXyXBzkyqzhlKsgzXKsJtB2XZcWoXH\r\n\t WtNyyhiD1w84rIHmCosuKrhrFFI50+ZihXxXhxek=',), 'content-type': ('text/plain; charset="utf-8"',), 'content-id': ('<8DEF3B2930D4004EB38802D09A7F5EDE@mairie-email-test.fr>',), 'content-transfer-encoding': ('base64',), 'mime-version': ('1.0',)},
    attachments=[
        dict(
            filename='',
            content_id='8DEF3B2930D4004EB38802D09A7F5EDE@mairie-email-test.fr',
            content_disposition='',
            content_type='text/plain',
            payload=b"Bonjour.\n\nUne nouvelle demande vous a \xc3\xa9t\xc3\xa9 transmise via le formulaire de contact du site www.saintnazaire.fr\n\nVotre message : onjour,\n\nJe voulais vous alerter que le pizza\xc3\xafolo du camion ambulant PASTA PIZZA de Vill\xc3\xa8s Martin du dimanche ne porte pas de masques pour confectionner ses pizzas et pour parler \xc3\xa0 ses clients; pas de gel hydroalcooloique non plus; travaillant dans les h\xc3\xb4pitaux je suis constern\xc3\xa9e de voir encore des professionnels et en contact avec un public de ne pas respecter le port du masque; il contamine ses produits, les clients ...\nCe n'est pas normal de ne pas contr\xc3\xb4ler ces professionnels ambulants.\n\nMerci beaucoup\n\n\n\nMerci.\n",
        ),
        ],
    from_values=EmailAddress(name='email-test.fr', email='ne-pas-repondre@email-test.fr'),
    to_values=(EmailAddress(name='Courrier', email='service.courrier@mairie-email-test.fr'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(EmailAddress(name='HELOU', email='emmanuellehelou@orange.fr'),),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='REDACTED',
    from_='redacted@attglobal.net',
    to=('', '@mailman.enron.com'),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(2001, 11, 27, 15, 2, 35, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=57600))),
    date_str='Tue, 27 Nov 2001 15:02:35 -0800',
    text='',
    html='',
    headers={'message-id': ('<001301c17797$9cd0ef30$a3ab620c@vaio>',), 'from': ('"SCS_2" <redacted@attglobal.net>',), 'to': ('<Undisclosed-Recipient:@mailman.enron.com;>',), 'subject': ('REDACTED',), 'date': ('Tue, 27 Nov 2001 15:02:35 -0800',), 'mime-version': ('1.0',), 'content-type': ('multipart/mixed;\r\n\tboundary="----=_NextPart_000_000F_01C17754.8C3CAF30"',), 'x-priority': ('3',), 'x-msmail-priority': ('Normal',), 'x-mailer': ('Microsoft Outlook Express 5.00.2919.6700',), 'x-mimeole': ('Produced By Microsoft MimeOLE V5.00.2919.6700',), 'return-path': ('redacted@attglobal.net',)},
    attachments=[],
    from_values=EmailAddress(name='SCS_2', email='redacted@attglobal.net'),
    to_values=(EmailAddress(name='Undisclosed-Recipient', email=''), EmailAddress(name='', email='@mailman.enron.com')),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import unittest

from tests.utils import MailboxTestCase, TEST_MAILBOX_NAME_SET, get_test_mailbox
from imap_tools.errors import MailboxCopyError
from imap_tools.consts import MailMessageFlags, SortCriteria
from imap_tools.query import A

TEST_MESSAGE_DATA = b'From: Mikel <test@lindsaar.net>\nTo: Mikel <raasdnil@gmail.com>\nContent-Type: text/plain; charset=US-ASCII; format=flowed\nContent-Transfer-Encoding: 7bit\nMime-Version: 1.0 (Apple Message framework v929.2)\nSubject: _append_\nDate: Sat, 22 Nov 2008 11:04:59 +1100\n\nPlain email.\n'  # noqa


class MailboxTest(MailboxTestCase):
    base_test_msg_cnt = 6
    test_chunks_size = 4

    @classmethod
    def setUpClass(cls):
        # clear temp folders
        for test_mailbox_name in TEST_MAILBOX_NAME_SET:
            mailbox = get_test_mailbox(test_mailbox_name)
            mailbox.folder.set(mailbox.folder_test_temp1)
            mailbox.delete(mailbox.uids())
            mailbox.folder.set(mailbox.folder_test_temp2)
            mailbox.delete(mailbox.uids())

    def test_action(self):
        for mailbox in self.mailbox_set.values():
            mailbox.folder.set(mailbox.folder_test_base)

            # SORT
            if mailbox.mailbox_name == 'ZIMBRA':
                found_msgs = tuple(mailbox.fetch(
                    bulk=True, headers_only=1, sort=[SortCriteria.SIZE_ASC, SortCriteria.FROM_DESC]))
                self.assertEqual(len(found_msgs), self.base_test_msg_cnt)

            # FETCH
            found_msgs = tuple(mailbox.fetch(bulk=True, headers_only=1))
            self.assertEqual(len(found_msgs), self.base_test_msg_cnt)
            found_msgs = tuple(mailbox.fetch(bulk=3, headers_only=1))
            self.assertEqual(len(found_msgs), self.base_test_msg_cnt)

            # FETCH nonexistent
            nonexistent_criteria = A(uid=['1000000000'])
            nonexistent_msgs1 = tuple(mailbox.fetch(nonexistent_criteria, bulk=False))
            self.assertEqual(len(nonexistent_msgs1), 0)
            nonexistent_msgs2 = tuple(mailbox.fetch(nonexistent_criteria, bulk=True))
            self.assertEqual(len(nonexistent_msgs2), 0)

            # NUMBERS
            found_nums = mailbox.numbers()
            self.assertTrue(bool(found_nums))
            self.assertTrue(all(type(i) is str for i in found_nums))

            # NUMBERS_TO_UIDS
            found_uids = mailbox.numbers_to_uids(found_nums)
            self.assertTrue(bool(found_uids))
            self.assertTrue(all(type(i) is str for i in found_uids))

            # UIDS
            found_uids = mailbox.uids()
            self.assertTrue(bool(found_uids))
            self.assertTrue(all(type(i) is str for i in found_uids))
            self.assertEqual(set([i.uid for i in mailbox.fetch(headers_only=True, bulk=True)]), set(found_uids))

            # cnt
            self.assertTrue(
                len(found_msgs) ==
                len(found_nums) ==
                len(found_uids) ==
                self.base_test_msg_cnt
            )

            # APPEND
            if mailbox.mailbox_name not in ('MAIL_RU', 'YANDEX'):
                mailbox.folder.set('INBOX')
                q = A(subject='_append_')
                mailbox.delete(mailbox.uids(q))
                self.assertEqual(len(list(mailbox.numbers(q))), 0)
                mailbox.append(TEST_MESSAGE_DATA)
                self.assertEqual(len(list(mailbox.numbers(q))), 1)  # YANDEX 0!=1 in test only, strange
                mailbox.delete(mailbox.uids(q))

            # COPY
            mailbox.folder.set(mailbox.folder_test_base)
            mailbox.copy(mailbox.uids(), mailbox.folder_test_temp1)
            if mailbox.mailbox_name != 'YAHOO':
                # YAHOO:
                #   imaplib.IMAP4.error: UID command error: BAD [b'[TRYCREATE] UID COPY failed -
                #   No mailbox exists with name - "__nonexistent_folder__"']
                with self.assertRaises(MailboxCopyError):
                    mailbox.copy(mailbox.uids(), '__nonexistent_folder__')
            self.assertEqual(len(list(mailbox.numbers())), self.base_test_msg_cnt)
            mailbox.folder.set(mailbox.folder_test_temp1)
            self.assertEqual(len(list(mailbox.numbers())), self.base_test_msg_cnt)

            # MOVE
            mailbox.folder.set(mailbox.folder_test_temp1)
            mailbox.move(mailbox.uids(), mailbox.folder_test_temp2)
            self.assertEqual(len(list(mailbox.numbers())), 0)
            mailbox.folder.set(mailbox.folder_test_temp2)
            self.assertEqual(len(list(mailbox.numbers())), self.base_test_msg_cnt)

            # FLAG
            mailbox.folder.set(mailbox.folder_test_temp2)
            mailbox.flag(mailbox.uids(), MailMessageFlags.FLAGGED, True)
            self.assertTrue(
                all([MailMessageFlags.FLAGGED in msg.flags for msg in mailbox.fetch(bulk=True, headers_only=1)]))

            # DELETE
            mailbox.folder.set(mailbox.folder_test_temp2)
            mailbox.delete(mailbox.uids())
            self.assertEqual(len(list(mailbox.numbers())), 0)

            # COPY chunks
            mailbox.folder.set(mailbox.folder_test_base)
            mailbox.copy(mailbox.uids(), mailbox.folder_test_temp1, self.test_chunks_size)
            self.assertEqual(len(list(mailbox.numbers())), self.base_test_msg_cnt)
            mailbox.folder.set(mailbox.folder_test_temp1)
            self.assertEqual(len(list(mailbox.numbers())), self.base_test_msg_cnt)
            # MOVE chunks
            mailbox.folder.set(mailbox.folder_test_temp1)
            mailbox.move(mailbox.uids(), mailbox.folder_test_temp2, self.test_chunks_size)
            self.assertEqual(len(list(mailbox.numbers())), 0)
            mailbox.folder.set(mailbox.folder_test_temp2)
            self.assertEqual(len(list(mailbox.numbers())), self.base_test_msg_cnt)
            # FLAG chunks
            mailbox.folder.set(mailbox.folder_test_temp2)
            mailbox.flag(mailbox.uids(), MailMessageFlags.FLAGGED, True, self.test_chunks_size)
            self.assertTrue(
                all([MailMessageFlags.FLAGGED in msg.flags for msg in mailbox.fetch(bulk=True, headers_only=1)]))
            # DELETE chunks
            mailbox.folder.set(mailbox.folder_test_temp2)
            mailbox.delete(mailbox.uids(), self.test_chunks_size)
            self.assertEqual(len(list(mailbox.numbers())), 0)


if __name__ == "__main__":
    unittest.main()



import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='',
    from_='xxx@xxxx.xxx',
    to=('xxxxxxxxxxx@xxxx.xxxx.xxx',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(2005, 5, 10, 15, 27, 3, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=68400))),
    date_str='Tue, 10 May 2005 15:27:03 -0500',
    text="Test test. Hi. Waving. m\r\n\r\n----------------------------------------------------------------\r\nSent via Bell Mobility's Text Messaging service. \r\nEnvoy par le service de messagerie texte de Bell Mobilit.\r\n----------------------------------------------------------------\r\n",
    html='',
    headers={'return-path': ('<xxx@xxxx.xxx>',), 'received': ('from xxx.xxxx.xxx by xxx.xxxx.xxx with ESMTP id C1B953B4CB6 for <xxxxx@Exxx.xxxx.xxx>; Tue, 10 May 2005 15:27:05 -0500', 'from SMS-GTYxxx.xxxx.xxx by xxx.xxxx.xxx with ESMTP id ca for <xxxxx@Exxx.xxxx.xxx>; Tue, 10 May 2005 15:27:04 -0500', 'from xxx.xxxx.xxx by SMS-GTYxxx.xxxx.xxx with ESMTP id j4AKR3r23323 for <xxxxx@Exxx.xxxx.xxx>; Tue, 10 May 2005 15:27:03 -0500'), 'date': ('Tue, 10 May 2005 15:27:03 -0500',), 'from': ('xxx@xxxx.xxx',), 'sender': ('xxx@xxxx.xxx',), 'to': ('xxxxxxxxxxx@xxxx.xxxx.xxx',), 'message-id': ('<xxx@xxxx.xxx>',), 'x-original-to': ('xxxxxxxxxxx@xxxx.xxxx.xxx',), 'delivered-to': ('xxx@xxxx.xxx',), 'importance': ('normal',), 'content-type': ('text/plain; charset=us-ascii',)},
    attachments=[],
    from_values=EmailAddress(name='', email='xxx@xxxx.xxx'),
    to_values=(EmailAddress(name='', email='xxxxxxxxxxx@xxxx.xxxx.xxx'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Соберите всю почту в этот ящик',
    from_='hello@yandex.ru',
    to=(),
    cc=(),
    bcc=(),
    reply_to=('foma@company.ru', 'petr@company.ru'),
    date=datetime.datetime(1900, 1, 1, 0, 0),
    date_str='',
    text='',
    html='<html><head><meta http-equiv="content-type" content="text/html; charset=utf-8"></head><body bgcolor="#ffffff" text="#000000"><meta http-equiv="Content-Type" content="text/html; charset=UTF-8">\n<title>Соберите письма из других почтовых ящиков в Яндекс.Почте</title><font color="#000000" face="Arial"> Здравствуйте!<br><br> Если у Вас уже есть почтовые ящики, куда приходят письма, Вам будет удобнее хранить и читать все письма в одном ящике.<br><br><table cellpadding="0" cellspacing="0"><tbody><tr><td valign="top">\n<a href="https://mail.yandex.ru/neo2/#setup/collectors"><img src="cid:collector.jpg@parts.yandex.ru" alt="Сборщик писем" width="135" border="0" height="100"></a>\n</td><td valign="top"> <font color="#000000" face="Arial"> В Яндекс.Почту можно скопировать всю переписку и адреса собеседников из ваших старых ящиков. С ящиками ничего не случится – они продолжат работать и принимать письма, а на новый адрес в Яндекс.Почте будут приходить копии этих писем.<br><br>Чтобы собрать всю почту и адреса в один ящик —\n<a href="https://mail.yandex.ru/neo2/#setup/collectors">\nнастройте сбор почты</a>. Для этого введите адрес ящика и пароль от него.<br><br>\n<a href="https://mail.yandex.ru/neo2/#setup/collectors">\n<font size="5">Настроить сбор почты</font></a></font></td></tr></tbody></table></font>\n</body></html>',
    headers={'content-type': ('multipart/related; boundary="===============1696383123=="',), 'mime-version': ('1.0',), 'reply-to': ('=?UTF-8?B?0L/RgNC40LLQtdGC?= <foma@company.ru>,\r\n =?UTF-8?B?0L/QvtC60LA=?= <petr@company.ru>',), 'from': ('=?utf-8?b?0K/QvdC00LXQutGB?= <hello@yandex.ru>',), 'subject': ('=?utf-8?b?0KHQvtCx0LXRgNC40YLQtSDQstGB0Y4g0L/QvtGH0YLRgyDQsiDRjdGC0L4=?=\r\n =?utf-8?b?0YIg0Y/RidC40Lo=?=',), 'message-id': ('<20110815165837.A26162B2802A@yaback1.mail.yandex.net>',), 'the-check': ('1', '2')},
    attachments=[
        dict(
            filename='collector.jpg',
            content_id='collector.jpg@parts.yandex.ru',
            content_disposition='attachment',
            content_type='image/jpeg',
            payload=b'\xff\xd8\xff\xe0\x00\x10JFIF\x00\x01\x02\x00\x00d\x00d\x00\x00\xff\xec\x00\x11Ducky\x00\x01\x00\x04\x00\x00\x00F\x00\x00\xff\xee\x00\x0eAdobe\x00d\xc0\x00\x00\x00\x01\xff\xdb\x00\x84\x00\x04\x03\x03\x03\x03\x03\x04\x03\x03\x04\x06\x04\x03\x04\x06\x07\x05\x04\x04\x05\x07\x08\x06\x06\x07\x06\x06\x08\n\x08\t\t\t\t\x08\n\n\x0c\x0c\x0c\x0c\x0c\n\x0c\x0c\r\r\x0c\x0c\x11\x11\x11\x11\x11\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x01\x04\x05\x05\x08\x07\x08\x0f\n\n\x0f\x14\x0e\x0e\x0e\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\xff\xc0\x00\x11\x08\x00d\x00\x87\x03\x01\x11\x00\x02\x11\x01\x03\x11\x01\xff\xc4\x00\xba\x00\x00\x01\x04\x03\x01\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x03\x04\x05\x06\x01\x02\x08\x07\t\x01\x00\x01\x05\x01\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x02\x03\x04\x05\x06\x07\x10\x00\x01\x03\x03\x02\x02\x05\t\x01\n\x0b\t\x00\x00\x00\x00\x01\x02\x03\x04\x00\x11\x05\x12\x06!1AQ"\x13\x07aq\x81\x91\xa12\x14\x15\x08\xb1\xd1Bbr\x92\xa2#3s\xd3\xc1\xe1\x82\xb2\xc2CSc\xb3\xc3\x16R\xd2\x83\x93$D%E\x18\x11\x00\x02\x01\x02\x01\x08\x06\x06\n\x02\x03\x01\x00\x00\x00\x00\x00\x01\x02\x11\x03\x04!1AQ\x91\x12R\x05aq\x81\xa1\xb12\xf0\xc1\xd1"\x13\x15\xe1Bbr\x82\xb2\xc23\x06\x16#$\xa2s4\x14\xff\xda\x00\x0c\x03\x01\x00\x02\x11\x03\x11\x00?\x00\xef\xea\x00(\x00\xa0\r\x1cy\xa6\x8biuiB\x9dV\x86\xc2\x88\x1a\x95bl:\xcd\x81\xa5\xa0\xa97\x98\xde\x90@\xa0\r\\Z\x1aB\x9cp\x84\xb6\x80T\xa5\x1e@\x0e$\xd2\xa4\xdb\xa2\x11\xba*\xb3)RV\x90\xa4\x9b\xa5B\xe0\x8eD\x1aF\xa8*fh\x00\xa0\x04b\xca\x8f5\x84I\x8a\xe0u\x85\xdfC\x89\xe4lH>\xa2)\x13O0\xe9A\xc5\xd1\xaa1jQ\xa1@\x05\x00\x14\x00P\x01@\x05\x00\x14\x00P\x04V\xe2%\xbcp\x94\x13\x7f\x84~<\x85\x1e\xa6\xday\x05\xc5z\x11\xa8\xd3\xe1\x9c\x9e\xcf\x9a\x9a\xd3]\xc4\xad0\x80(\x01\xbc\xe4\x07aIm^\xea\xdaZM\xb9\xd8\xa4\x8a\x92\xdb\xa4\x93\xe9\x19qV-t\x1ac\x15\xab\x1b\rW\xb9,6o\xe7H\xa7^T\x9c\xba\xd8\xdb.\xb0\x8fR\x1d\xd4$\xa6\t\xb0\'\xab\x8f\n\x00\x8f\xc1B\xf9v\x1e\x1424\xad\xb6\x93\xacZ\xdd\xb5v\x95\xc3\xceM2\n\x89"{\xf3\xdf\xb8\xe5\xd2H\xd3\xc8\x02\x80\n\x00\x87\xce\xe7Q\x89T(l\xa0=\x95\xc9\xbc#\xc1\x8f\xd6x\x15\xb8\xabq\xd0\xda{J\xb7E2R\xa7[,Y\xb3\xbfV\xfc\xb1U~\x9d$\xc5<\xae\x14\x00P\x01@\x05\x00#.:e\xc5~*\xfd\xc7\xdbSJ\xbf\x11e\x82\x0f\xdbJ\x9d\x18\xe8\xca\x8d0\x8c\xa3\xdd\x84-IS\xe8\x03\xbe\xd2og\x08\xd4G\x93\x9d#\x11\xb5\\\x82\xa1@\xf27\xb5\x02\x1a\xb8\x9dhR/m@\x8b\xf9\xc5\xa9S\xa3\x11\xaa\xa1\x9e\x19D\xe2\xe1j\x1aO\xc3\xb5py\x83\xa7\xf8\xaak\xff\x00\xb9.\xb6Eg\xc9\x1e\xa4>J\x92\xb4\xa5hPR\x14\x01J\x81\xb8 \xf2 \xd4\x04\xc6h\x027!\x9b\x81\x8fBT\xb7C\x8b2\x11\x0c4\xd1\nY}\xc1\xa8#\x98\xb1\t:\xcd\xfa)R\xadi\xa0M\xe4Be\xfcE\xdb\xb8_\x8a2\xd6\xe2\xbe\x11hC\xa1\xa0\x16\xad+\x17\xd7k\xdfM\xfb>zktM\xe8\x89f6%(\xefh\xf6\x13\x839\x88\x0f\xe3\xa3.k(\x97\x96B\x9c\xc6\xc6R\xd2\x1d}\x08Gx\xa2\x84\xde\xea\tO\x15[\x95&\xf2\xdaD\xa1&\x9bK"\xce=\xefS\xdfw\x1cu\xe9\xd7\xe4\xb5\xedN\x18y\xa7\x87\xb9\x07w\xa6\xea\xdc\x1b\xd5\xd2\xbf\x96\xc3Y\xc4aR\x7fW\xdd\xa0\x85:\xb1\xc4\xf16O\xac\xfa*Z{\xf2r\xecF\xde:\x1f\xfc\xf6akK\xf7\xa5\xea=8\x13s\xd4*\xd9\x88f\x80!wz3k\xdb\x19_\xf4\xd4\x9f\x85\xcf":\xdd\xc7\xbcP\x97\x07~\xd0\xd6\x94\x94\xa8(\x10\xbd:\x0f\x0e\x9a\x8e\xe6\xf6\xeb\xdd\xceZ\xc2\xbbj\xec~"\xack\x97\xa8\xe3\x98\xdfW\xbb\xe6NS\x0e$3\x11\x88\xcc\xba\x88Y\x946\xd9\xd0\xea%8\x96\x83\xe0(\xa8\xa1m\x93~\n\xd2zEd\xc3\x1b7(\xd71\xd9_\xe4xxZ\x9b\x8dj\xb3t{Q\xe9\xdbk\xc4\xad\xdb\x1f%\xb80\xb2\xa78\xe9aa\xe8j\x7f\xf4\x8bB$%F\xc0\xaa\xe6\xc1hU\xbc\xf5\xabg\xcd4\xf4:\xf63\xcfp\xca\xae\xe2\x7fU\xa6\xba\x99+\x8c\xf1Wr\xc8rlW\x14\x15(b\x1c1\xdf\xe0\x00\x96\xdfx\x03\x85\x16)\xd5q\xd5\xc6\x96M\xa6\xfa\x8b\x96\xd2mW5QOk\xc5\xfd\xc3\x07\x1a\xeey\xe5\xad\xd7\x8c\\n]\xf5\x83`\xa2\x85\x14>\x9b\x1e\x82\x94\x94\x9f=.=|+\xb77s-\xd6\xbbL\x1f\x8b%\tKJ\xdd\xf1\xa3\xf0%7&\xf4\xccG\xcbl\xfc\x8e6S\xec\xc7\xc9Ka\xe2\xd0Q\xba\xd9\x92\xd3\xc9\x01V\xe7\xd9#\x85GZ\xc6\x0f\xa7\xdau\x16\x12q\x9eO\xa8\xfcQ=\xb5<S\xc9\xc5\x89!\xb9c\xe2\x94\xdc\xf7T5(\x85)\x0bzBJ|\x80\x06\xc5\xbc\xb5w\x10\xa9%MQ\xf01\xad\xb7O\xc4\xfcY\x19\x1b\xc4\xcd\xcd\x9a\xc3\xee\x07e\xbe\x96\xa1\x98\x12KL4\x84\xa5(Iiv\x00\x81~\xcd\xb9\xde\xb3\xed]w,\xcao>R~O\'{vR\xe3K\xb3x\xa9m}\xf1\xb8\xb1R\xa4dQ9\xd7\\\x8f(\xc2i.\xa8\xa9\xa1\x1e\x14&\xd3\xdd\xe9\xbd\xb4\x82\x9e]|j|\x14w\xee4\xf3o%\xdc\x8dnn\xd4-\xdbk?\xc3r}nR~\xc2\xdf\x91\xf1\'s\xb1\x92\xc7\xb2\xcc\xa0&\xe5#\x85Kx$]\x01\x94\x85\x90\x81\xc8\\\xac\x03aL\xc5\xc9\xc5%\x1d2*\xc2)\xc5WSc=\xb3&fGs\xc3rK\xcbt\x06\xa7\xe5\x1c%D\xdd\xe7\xddRB\xfa\xb5Y\x00y\xabR\xcf\xbb\x85\xb8\xf8\xa7\x15\xe2\xcc\x14\xab\x88\x87B\x9c\xbc\x11\x13>k\xf2\xb1;\xb9\xd7\x15uK\xc8\xb7\x05\xa5~\x0cf\x9bM\xaf\xe4R\xcdd\xdf\xfd\xb9\xf4\xe4\xf5\x1d-\xbc\xcb\xa2>,n\xac\xd4\xbcw\xcb\xf7c/(\xe6\xb1\x902\xcc\xc0\x92\xa5\x15\x16\xa1kDV\x1aJI\xb0\x1a\x92T:kNxx\xbcM\xabif\x8cS\xed\xa5L\xeb8\x99\xc7\x05zM\xe4r\xc9\xd9_ar\xcfo\xdd\xd8\xcch\x10Q84\xf3\xf8U"{\x9aR\xa5)\xe7Kl6\xe6\xa2.\x15\xa8\xad\\*\x966I\\\x92\x86l\xb4\xdbD3\r)F\xe47\xb2\xd25\x97Nb\x9b\xf4\xdb\xe2~\xe7\x91+#\x83t7+h\xc0t\xc5\xc60\xd3Hm\xe2\xe3\xaf9\xa5z\xc5\xae\xa7\t\xd4\xadF\xddUK\x04\xdc\x9c\xa2\xbc\xb1:\xfeob2P\x9b\xc9r\xe5[\xd4\x92H\xebT\x8b\x0bzO\x9c\xd5\xf3\x93\x0e\x9a\x00\xcd\x00|\xc0\xf1\xb3j/hx\xb7\xb9\xf6\xebh\rE\x9a\xb7\xdc\x80\x10,\x90\x99\t\xf8\x96\x02\x7f\x16\xe1>\x8a\xe6\xef\xc7rO\xa1\x9e\xa1\x81\xbd\xf1\xad\xc5\xf1\xc2\x9f\x89d\xf1G\xb9\xed\xac\xb229\x9c\x0ey?\xaa\xdc8\x86]_\xedP\x1bp\x8fF\xa7+r\xd3\xad\xc4\xf8\xa3\xe0y\x8c\xa1\xf0\xf1\x92\x87\x14d\xb62\xc9\x8fe\xb6\xf7T8\xeb\xf7\x1f\x12\xa3(z\x96?\x9cjI\xf9\x97j\x1d\x17\x93a@\xc9\xb5m\x99%\xabv\x86\x0etey\x15\x12J\xd3\xec\xa7s\x1c\xb2o]\xb8>\xe3\x12\xea\xa3\xba\xba_\xe7~\xd2\xe3?\xf4\x91\xbc1Z\xad\xdb8\xbbz\x19Q\xa8c\xe4\x87\xa6\xb3\xa7\xb1\xe5\x9f\xdc~1\x17\x8e\x96\xbe]9\xc2;_\x1a\xfa\x90G\x03`f\xab\xed5{\x14\xfd\xe5\xd5\x1f\xcabA\xd2+\xefK\xd65\xc3\xe8F\xd6\xcf\x84\xf0\xd3\x8fu\xb1\xe7]\xd1\xfd*\xc8\xc2\x7f\xe5\xeb\xaf\x89?\xf1\xff\x00\xdb\x83\xfbU\xf1er1\xbe=\xf7\x12x\xbb\',\xeaI\xe4u\xbe\x18Mi\xf2\xcf=~\xd4\x9e\xca\x9a|\xf9\xe4Q\xd5n\xda\xda\x97\xb4\x9c\xcb-\t\xdd\xa8O\xf5x\xf8\x04\x8e\xae\xd2\xd2?\xcb\xaa\x98\x8c\xb3\xb6\xbbFV\x91}\x08\xb7\xec\xd8\xe5\x9c\x9eE\xd5\x02\x0c\x1cdX\xda\xbf\r\xc4\x05\x91\xe7\xed\xd6\xbf\x97\x07mqJOfC\x9f\xc3\xaa\xdeo\x86\x11[[eD\xbdm\xb3\r\xf5\x1e\xcc\xdc\x94\xd9\xeb\xf2\xa4Iq@\xfeKB\xb3\x1cw\xf7c\xc54tS\x96\xe4&\xf5%\xdc\x86\xf9\x08\xcbS8\x9cA\x1d\xb7\xbeY\x05I\x1cx\x00f=\xedX\xbdm\xd8\x92x\xcb\x974A>\xe5\x90\xc6\xbb\x1a`\xad[\xe3\x97\x8b^\xc6#\xe2\xa6k\xe5x\xed\xc5\x92B\xac\xb6B`\xc4\xfcf\x1b\x08H\x1f\xf1d~msw\xe7L\xbe\x99>\x96kr\xfb_\x1b\x11Mm/[-_J\xbbHC\xc2\xc2\x94\xe2=\xedy\x07n.9w,\x03\xe5\xe0\xa5\x8f5I\x81\x86\xe5\x8a\xe9\x91\xbb\xce\xefV\xf4\x92\xfa\xb4\x82\xec\xcb.\xfc\x87Q_\x8d\xaa\xd1\xcb\x99\xa0\x02\x808\xb7\xeb\x87m*\x16Wlo\xd8\xe9\xe0Ra\xc9 }\xf4e\xf7\x88$\xfe\x12\\P\xfeMd\xe3a\xef\'\xadP\xec\xf9\x15\xff\x00\xf15\xa6\x12R\xecy\xfc;\xca\xdf\x86\xd3[^\xd3\xdb\xee\x95]X\x1c\xb3\xf8\xe5\x9e\xa8\xf2\x16T\xd7\xa3D\x84\xfa\xa9\xf8i\xd6\x10\x96\xa7M\xb9\x0c.\x7fk\xe0c\xa3%\x9byl\x96C\xd5e\xa1,n\x1c,\x9bX*j\x02\xad\xd0^mI\xfbmZ\x17U)\xd0\xcc\xe6\xa8\xda\xeb*y\xd8\x89g\x1f\x98\x86mf\xce\xe0\x8d\xa7\xc8\xbf\xd3\x0f\xe7R\xe3\xb2\xc6\x0f]\xaf\xcb#\x17\x11\xfb\x97:\x9f\xe9d\xd3\xba\x1ec\xc2\x80y9\xf2\xcfdu\x13PG\xc9\x0fM\x0c\xe9ly\'\xf7?TE\x94\xda[\xc2Np\x1fzT\xb0\x0f\x99\x12\x7f\xde\xab\x98\xc7\x97\xb1~S\x05\xba[\xafL\xbfP\x9e1\xb4\xb7\xb4r\xca\xb0\xed";7?\xdeJl\x1a\xcc\xc2\xff\x00\xe5\x8f\xa6\x92\xe7#\xc9b\x1f\x89\xff\x00\xc6Eg\x08\xdf\x7f\x8f\xc54\xaerR\xd2\xadn\x07\xe2\xe7\x97=\xa0V\x8f.\xc9\n\xfd\x99\xbd\xb5\xf6\x9a<\xf7.&Q\xd5(Gb^\xc2FY\x12w6p\xa7\x8a\xbb\xb8\xf1\x91\xe7^\xb2G\xadb\xa9\xdf\xfd\xe5\xd1\x16W\xc4:Z\x97\xa6\x83\xd0\xe0:\x98XM\xd3\x96 \x04\xae[\xe9J\x8fJ"$ \x7f\x86kc\x13\xee\xc2\xd4uB\xbb[ff\x125\x9c\xde\xb9SbH\xa0\xe4c)\x18\x1d\xb9\x8aM\xfb\xd3\x01\x94*\xdf\xdaJJ\x12}\xaf\x1a\xaf\x85U\xbfo\xec\xefKb/\xe3\xa5\xfe\xbc\xfe\xd3\xa6\xd7BN9nV\xf8\x88\xb5\x80#A\x13\xb2Nu\x046\xae\xe1\xbf\xcdl\xd5\x8c;\xdd\xb1v|M.\xfa\xbf\x02\x0c_\xefZ\x86\x88F\xbd\xdfI\xe5^*\xbf#(\xde\xdc\xdbm\\\xcc\xcdJ\x13\x1fG3w\x16]\x00\xff\x00)\xe6\xff\x00&\xb9\xacKmn\xe9\x95\x16\xdc\xac\xe9\xff\x00\x8e\xc1F\xb7\xa5\x9a\x11r;/\xc2\xcc\x0bX=\xb2\xd2\x1bH\tXKM~\xc62{\xa4\xfa\xc8R\xbd5\xb4\xd6\xeaQZ\x11\x91\x8a\xb8\xe5,\xb9\xf3\xbe\xb7\x95\x97q\xd7\xd7\xe9\xa6\x94\xcc\xd0\x01@\x1eA\xf55\xb4\x93\xbb\xbc\x1e\xce\xb2\x96\xcb\x92\xb1iNN8\x02\xe4\x18\xf7\x0e\x1fCj]T\xc5\xc6\xb6\xeb\xab)\xb5\xc9\xee\xeeb\x14^i\xa7\x1d\xb9\xbb\xe8q\x8f\x84\x19\x17d\xe07\x06/W\xe9\x8cX\xd9\x06\x87O}\rJ\x8e\xe1\xf3\xf6Z\xaa\x18\x7f,\xe3\xdb\xeb-\xff\x00\'\xb6\xe7f\x174\xd2\x9d\xb1=\xc7-\x94\x0fc\xe0\xe4\x9bW\xb8\xe49@\xf9\x03\x88Q\xf6V\xc5\xdc\xb1o\xb4\xc1r\xde\x92|I=\xa8a\xbb\xa4\x04\xe4\xf3\xed\x13`\xa9rT<\xd2\xe1\x03\xf6\x8a~+-\xabo\xa2\xe2\xf5\x98\x98\x85\xfeW\xd3\x1f\xd1\xf4\x0e>1)\x8b\xe1"uX\x8f\x81?\x93\x19uR\x1eHzhgE\x87\xfd\xa9\xfd\xcf\xd5\x11\xcc\x99\xa1\xad\xb8\xf9*\xb9[\xd2\xb4\xfe1\xd4?\xa5Vq\xcf?\xdd\xfd&\r\xdc\x96\x9f\xe3\xf5\x98n[L\xec,\x9b\xcbW\xfd\xccP\x90O\xdf!e\xc3\xecER\xb3\x93\r\x03W\x92C\xfcV\xd6\xb4\xfb\xf2z\xc8}\xbc\xf2\x03\xd86\n\xac\x19j\x00P\xe9\xbbq\xdcx\xfbMh\xe0\xd5,\xfe\x15\xde\xd1/4\x96\xfe2]7%\xddQ\xde\xdf\x90\xdc\xac\xfc\x97Tn\xdb\xf9v\x9b\xe3\xc0\x94\xc7Kd\x8f\xcc5B\xe6[\xd3\xeaK\xbc\x8f\x15\xe5\xa6\xb9z\xcb^K"\x88\xfe\x16\xca:\xec\xf4\xd4:\xe7\x0ez\xe6\x15\x91\x7f?z+_\x1c\xff\x00\xca\xd7\nKbE>^\xbd\xd8\xbdm\xcb\xbd\xb2\'\'!\xaf\xf5<&u\x0e\xe6\x1fv\xabt\x04DB\xdc\xff\x00)5\x1d\x8c\x92\x9c\xb8m\xfefO\x8a[\xca\xd48\xa4\xbd\xa3\\b\x82\xd9\xdc\x92\xb5v\xfb\x88xVW\xf8o\xd8\xb9\xeduT\xfb\xbe\xe6\x16\x11\xe2m\xfa\x8a\xb7\xde\xfd\xfb\xb2]\x10E?\x03\x10\xee\xff\x00\x1b\xee\xc2{\xc8\xb8&P\xdct\x9fw\xbeY\x01\xb1\xebZ=U\x87f?\x13\x10\xb5EW\xd3\xb0\xed\xac\xa5g\x01\xff\x00d\xa9\xf8c\x95\xf8\x1d\xcb\x12* \xc1b\x1b_\xab\x8e\xd2ZO\x99\t\x02\xfe\xca\xd3n\xae\xa7))oI\xbdb\xe9\xbd\xbb\\\xeeyu_\x87\xb2\x90h\x1a\x00\xcd\x003\xcb"#\x98\xb9\xcd\xcfo\xbe\x82\xb8\xee\xa6K?\xed\xb4Pu\xa7\xa3\x98\xb8\xa4\x96l\xa3\xed\xb6\xa4\x9a\xcfS\xe7&\xd9\xd9\x19-\xaf\x9e\x91\x92\x8d\x94\x8c\xbck\xff\x00\x14\x84\xc7(s\xbc\x0cK\t!$\xf2\xbaV\x84\xab\xd7\\\xa5\xaecn\xdc\xebG\x9a\x87w\x8d\xc3O\x13i\xdb\xc8\xbd\xea\xed\xce[\x16\xac\x81\xc2\xa7\x13\xf3\x06C\x89d\xb0\x9749k\x02J\r\xb9\xf0\x06\xd5ms\x9bJ\n;\xaf"\xa6\x83\n\x1c\x8e\xeca\x18\xef*\xc5SOa\xbeq\xe9\xb9\x89\xd3$\xb79\xb6\xcc\xc0\xce\xa4\xad\xb5\xf0[lwJ7\x1dg\x95:|\xee\xd4\xad\xc6;\xaf\xddm\xe8\xd2\xa8V\xbb\xfcv\xf4\xa7\xbd\xbd\x1c\xd4\xd3\xd3\xed\x12uy@v\x88\x13\x1b\xb6\xd9KI\x90\x9d\x0b\xfd)i\nn\xe8\xe3\xc2\xf7\xe9\xa8c\xce-(\xc5n\xbc\x9dF\x8c9E\xd8\xc1\xc7yeT\xd3\xad?P\xb2\xe6\xe4\x1d\xc77\x00\xbe\x9dM\xb8\xe3\x8bV\x85i!kI\xb0\xf4\x0bS\xb1\x1c\xea\xdd\xc4\xfd\xd7\x95SF\xaa\x19\xf7?\x8e\xdd\x9c\x1cT\xa3\x96\xba\xf4\x98\x97/!#k;\x80C\x9a_z@\x91\xdf\x94\x92\x8b\x04-\x16#\x9d\xfbU\x17\xcd\xed|%\n<\x8b\xa0\xd2\xc0rk\x98e\x04\xda{\xbdz\xd3\xf5\tCVV,\xe4J*\nm\xb3p\x94\xa4\xde\xc9\x8f\xdc\x0eg\xd3V\xad\xf3\xeb1\x8d7^\x8dZ\x08\xa5\xc9.\xca\xee\xfb\x92\xce\xde\x9d!\x88N_\x1e\xf2\x1e[\x89Z\xc2\xe6?p\x08\xbb\xb2\x90\xe2\x1b<O\xdek\xe3U\xe3\xce\xac\xa9\xb98\xbc\xad=\x82\\\xe4wf\x97\xbd\x1d:\xc9\xec\xd6O!\x93\xc2B\xc2\xc7\xb3H\x8c\xe4u8\xa5\x90u7\x1c\xb4H\x16<\xc8o\xa6\xa6\xb9\xcf\xedNN[\xb2\xca\xfa\x06Z\xe47m\xc5-\xe8\xe4T\xd3\xa8b\xb4\xe5\x9f\xc9\xbb8\xc8i!\xc6\x96\xd0I\n$\x17BR\xa3\xc3\xc9\xab\xd7G\xcf\xec\xa8\xcd(\xcb\xdf\xa6\xad\x04\xb3\xe4\x97%v\x13\xdeT\x82\xe9\x14m\xac\xebp\x8cF\xe53\xad\xd9\xce\xe4\x1fr\xcb\x01JRV\x1bH\x1f\x83\xa8z\xa9\xd7\xff\x00\x90Z\xb8\xa2\x94e\xee\xaah*\xc7\x90]_Z>m\xe7\x9c\x9a\xf0\x1b\x0e\xf6\xcf\xdej\x9f\xb8\xe4\xa2k\xd9\x89\xc9:\xe2\xa5CJ\xdd%\x0c\xa4\x85\x91\xc1+X&\xddT\xdc\x173\xb4\xe6\xe2\x93\xac\xcdLf\x1a\xe7\xc0J\xaa\x90\x8f\xd3&vq\xb5t\x07\x1c\x04\xf0\xe0/\xe4\xa0\x0cj7)\xd2x[\x8f\x0bq\xf4\xd0)\xb5\x02\r2\x8d\x97\xb1\x93Y\x06\xc5\xc6\x1d@\'\xa3R\x08\xa4y\x87A\xd2H\xe0%\xe5]\x00\r7\xd0\x02}B\xd5\xe6S\xf35\xd2z\xacs\t+.\xe7\xdfi@\xe9&\xdfv\xa2\xca;!\x81\x96"\xc0\xad>\xb1\xf6\xd1A2\x1b|\xdd)$w\x88\x1d<\xc5\x14b:\x08\xaf?\x1d\x0e%\x85Jm\x0e\xae\xeaCZ\x92\x14\xa0\x9ed\x03\xc4\xda\x8d\xc9g\xa0o,\xc6\x9f=\x8a\xea\xdce2\xd0\xa7[\xb7x\x84\xa8\x12\x82x\x8b\x8e\x8b\xd28Ih\x1c\xa5\x16g\xe6\xed&\xff\x00\xa5\x04\xf9TM&\xeb`\xda59\xb6\xff\x00\xb6O\x0e\x17\x17\xa4\xdc`\x9a7Ns\xa9w\xbf.\xc9\xfb\x94n\xb1E[\xcc\xbf~\xc9U\xc7+\nZ\x06A\xcbyyJ\xe0\n\xfc\xd4\xe4\x86:\x16\xbf\x0f\xe4I\x99\xbdv\xf3.)A*\xc8\xc4$\x9e]\x97R\xaf\xe0\xadN\\\xbf\xd8\x8fY\x9f\x8fiX\x9fS;g\x9d\xc7Mw\xe7\x9c\x00\x00r\x1dg\xd6o@\x19\xa0\x02\x80\x13\x90\xda\x9d\x8e\xebI\xf7\x96\x85$_\x95\xc8\xb5\x02\xac\xe7\xcew#-\xbe\xc2\xcd\xd6\x07hp\x1ck\xcc\xafd\x9b\xebg\xa8\xc3,P\xcd\xd8\xee{\xc9A#\xa3\x95\xbe\xdab\x92$\xa0\xd1\xc6dp\xba~\xcf\xbbORA\xba$\x19wW\xba\x07\x94\xda\x9d\xbc\x86\xd0\xabnD>\xden\x1c\xd6\xd0\x14\xec\x18\xae\xcb\tO5!\xb7P\x1cH\xb0\xe9AU]\xb0\xd3\x83Z\xdd\n\xd7*\xa4\x9a\xd0\x86\x10\x9c\xc9c]\xc8\xccKZ\xe5\xc8^=\xd7\x91mJ\xff\x00\xabZ\xae\x808q\t!"\xa4\x9a\x8c\xe8\xb4-\xee\xe1\xb1\x94\xa3W\xd5\xdeH\xaf5\x98rS\x90\x98\x8a\xe3n*J\xdal|8u\xf44\xd3(p\x82\xde\xa0\n\x89W_*\x85Y\x86v\xf4k\xc9\x9fX\xf7zo6\xbd^\xa2{\x1a\xac\x94\x88,;:)\x8f,\x82\x1diCM\x94\t\x17\x02\xe6\xd7\x1cj\x9d\xc5\x18\xc9\xa4\xea\x8b\x10m\xc5U\x12H\x12\r\xbb \x0f)\xa8]5\x92\xe5\x1d\xa3\xe2Q\xc6\xc0\xf9\x01\xbdF\xdcGe\x17k\xe35\xdc%\x16\xeb&\x95J#Ze\xdf\xc2\xf4\xc8_\x88\x1bi$$\x7f\xe4c\x93et$\x95\x1f`\xad~V\xe2\xf1\x11\xa1\x95\xcc\x94\x96\x1eu\xd4w(\x1co]\xf1\xe7fh\x00\xe8\xa0\x02\x80\n\x00\xf9\xe18G\xef\xd4T\xe1+\xb9\xd4\x9b\xf4\x82k\xcb\xb1\x15\xf8\xb2\xebg\xac\xd9Kqu\x0cKm\xac( )`t\xa4^\xab\xd5\x92\xd1\t\xad\xa6\xc5\xae\xd2\x89\x1c=\xd3Bl\x1aF\x03\x08\xb8"17\xe5\xc0\xda\x96\xafX\xda#S\x8fes\x1b\x97\xf0ES\x1bmM!\xc1\xcc6\xb2\x14\xa1k\xdb\x89\x03\x9d9\\{\xb4\xaeA\xae\n\xb5\x13{\x17\x19\xf7\xddqX\xf2\xb7\x9eS+t\xdc\xdc\xaa)\xd4\xd1\xe0~\xf4\xff\x00\x1d9]\x92T\xaej\xf7\xe7\x11\xdb\x8b\xf4\xd4!3\x05\x1eJ\x9d\xef\xe1\x90\xeb\xcf|J\xdcC\x85\x0b\x0f\x04\x84k\x0bJ\x81I\xd24\xf04\xb1\xbd(\xe6z)\x98\x1d\xb8\xbd\x02\xf1\xa1*+M\xc7\x8a\xc6\x96ZN\x94\x80\xbb\xd8yI\xb95\x1c\xa7\xbc\xea\xc9c\x14\x95\x12\x1c\x06\xde\xb5\x96\x9b[\x91\xbdF\xd8\xea!V\xd9_+\x12I\xe3{S[\x17 \xf5\xa6\x1c\x1f\xd5\x92\x0f\x98Sj#\x92.\xde\x16\xc7y>!m\x93\xdd\x10>=\xbb\x9b\x82x!d\xfd\x95\xb5\xc9\x9dqQ\xed\xf029\xac\xbf\xd6\x9fW\xac\xed\x8a\xf4S\xcd\x82\x80\n\x00(\x00\xa0\x0f\x02\x95\xf4\xcf\x1d\xd7\x96\xe3y\xd1\xa1JQJU\x11:\x85\xc9<Oxo\xea\x15\xce]\xe4\x91\x9c\x9c\xb7\x9eW\xa8\xe9\xa1\xcfe\x14\x96\xe2\xda ~\x99\xdd\xb1\x03>\x80\x0f!\xf0\xc4}\x8b\x15\x17\xc8!\xc6\xf6\x0e\xf9\xfc\xb8;\xc4\xbf\xf9\x99\xe1\xff\x00\xbai^x\xea\xfd\xe57\xe4\x11\xe3{\x07\xff\x00`\x97\x02\xda&\xaf\xa6\xc9\xe9\xf72\xac\x13\xfb\x03\xfc.R|\x82<O`\xef\xec\x12\xe1[Y\xa9\xfap\xca\x11\xa7\xe6m[\xa6\xed\x1b\x7f\x89K\xf2\x08\xf1=\x82|\xfe\\+i\xaa\xbe\x9c2\x9alrM\x10:;\xa5[\xd4\x17G\xc8#\xc4\xf6\t\xf3\xe9p\xad\xa6\x87\xe9\xb3&x\x8c\x93\x02\xff\x00\xdc\x92}\xaeQ\xf2\x18\xf11\x7f\xb0K\x85m\x0f\xfek\xcb\x1eyV\x7f\xe4\x9f\xdeQ\xf2\x08q0\xfe\xc1.\x15\xb4Q\xbf\xa6\xac\x80\x1cr\xac\xfaYW\xef)~A\x0e&5\xf3\xf9p\xa1\xc3\x7fM\xf3Rx\xe5\x98\x03\xf6\n\xfd\xe5\x1f!\x87\x13\xd8\'\xcf\xa5\xc29G\xd3\xac\xbb\xf6\xb2\xcc[\xaf\xb8_\xef(\xfe\xbf\x0e&7\xe7\xb2\xe1\xef,\x9bO\xc1D\xed\xcc\xee?8\xeeQ/.\x03\x8au,\xb6\xc9N\xa5)\xb57\xc5Ef\xc3\xb5\xd5W0\x9c\xa2\x18{\x8ajU\xa1S\x13\xcd\xa5z\xdb\x83\x8d*z\xddn\x98a@\x05\x00\x14\x00P\x06\x0fE\x00f\x80\x0e4\x00P\x01@\x05\x00\x14\x00P\x01@\x05\x00\x14\x00P\x01@\x05\x00\x14\x01\xff\xd9',
        ),
        ],
    from_values=EmailAddress(name='Яндекс', email='hello@yandex.ru'),
    to_values=(),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(EmailAddress(name='привет', email='foma@company.ru'), EmailAddress(name='пока', email='petr@company.ru')),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='You may_be Eligible for Legitimate_Cash from_GovAgencies! ',
    from_='infoz@reactive-outpost.com',
    to=('someone@yahoo.com',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(1900, 1, 1, 0, 0),
    date_str='\r\n       <HR>',
    text='',
    html='',
    headers={'x-ymail-umid': ('1_28022_AGnHtEQAAW9xTQLt8wZPlyfni5U',), 'x-apparently-to': ('someone@yahoo.com via 68.180.199.105; Fri, 10 Dec 2010 19:20:19 -0800',), 'received-spf': ('pass (mta1007.mail.sp2.yahoo.com: domain of return@reactive-outpost.com designates 74.206.28.55 as permitted sender)',), 'x-ymailisg': ('EfAmUiocZAp0Gt06jFhMyq.RIPUVX9lzgOtsRqYzqYiHPTr1\r\n 0fU8Vw4OuGrVz8pSoGW6xDId01O9G9v_HqarLXv8V_3Z9ut5fddpRwyrVOpc\r\n 1NYVLhP.FzTcsd9snLKon1z0xEKDX0aWVgu6rOeJ3niXPtE3ubgKne3SWhrc\r\n 9Jh34ln.bbeJ52jQ7ToV0m5oC1_T47MCsj._NgxOknVeA1lAJbbtNAEclmXl\r\n SQvHnQENVjs9FKYmFsB8d1dSX61CsJq0OMSpC5aqnGFAV2DBPOggUD217rpT\r\n n.5Pe5NXv16E0mXO2gNKgtho5W72qSE.1nWBGc5Vl0h8XrXUj._O9Nkajzg2\r\n .klfTThF3zT2ThdTWgFl4lwkNjPKrc1EvlDcd1IPDQYwvMc1SEUpP_lddKwd\r\n aQiDt9G9Bu_Nf9vS5T97ZrS6pJJde4U0vrV872UEF.Mj2kpocFr_ba3fC6wP\r\n kUO.gj3xw2YQmo3I56NV66VndTOrSya2qAGpkCjkWtT6irAxwXakWlts.EFC\r\n iCRmdqsx7CN4UdCJw3vtDc7ASdV5Ty.kKy2GvIrHOFW.gFYGCXM7V0YnXBD1\r\n ho5ePgvP6hGNkrHA9MQzUKq7s6uikRvVPBR7ojjcxqpKOgilKuobsYeuEKZ.\r\n kOvWe6P3uZJxV4KVnGfBxCe9SU27RdVpdlWmI3cJc7ut2OfMUoTnI_dVBbK8\r\n 1O0tXTco9FYvL8IJfS4RzSnQOw7HDcqF4oNAeghagmlKAuvSCYk19XkqIdDd\r\n tzQO1K3DxMIdvS5ut39WQ.LoDu0b6BmFB.YDgUMF6zM3PtgzoJuVumOg1fvh\r\n jGf.3v5mgno63PiAoKoBSQkdCdf0GD_jPX1RX_Us405EVLsTjzyjiEno99Vq\r\n pxps1ab0rNal.g4Nep2ik_W7TgX6GCxUtZVFoHRbl4rA7gMPIPuF0MF5SkTN\r\n jd6vOu6eYRCyCBo_afBI_FkaG6J4gxis8FtAOpUFmXLW7Iwh2uVr4aoiv7ag\r\n Ee2U3XYQovYoYtzCsg.iAe97SjJcqINnps0DoC5ky9ijX9WSz4tJj_HgXWAo\r\n 2e8gh.25kkMg70QTFOdPONgQe3dF2g9wI7ELcIcMYSyMbvqqAY3OMTigxh9O\r\n _7PpaK_qHQ270JbYhnK53ZrNrIIwM1lhBjdjLfNjSaotnLT5.t1BobGskqhz\r\n 90CGlOIrzeI2xo_3c8Q.K8hceK_9oxsMP7TyML6J9KaEbV3lW0vHFUxXb21u\r\n 4bdKY3KBsxOPCA--',), 'x-originating-ip': ('[74.206.28.55]',), 'authentication-results': ('mta1007.mail.sp2.yahoo.com  from=reactive-outpost.com; domainkeys=neutral (no sig);  from=reactive-outpost.com; dkim=neutral (no sig)',), 'received': ('from 127.0.0.1  (EHLO reactive-outpost.com) (74.206.28.55)\r\n  by mta1007.mail.sp2.yahoo.com with SMTP; Fri, 10 Dec 2010 19:20:19 -0800', 'from localhost (127.0.0.1) by reactive-outpost.com id h0calo0n7lgf for <someone@yahoo.com>; Fri, 10 Dec 2010 22:08:27 -0800 (envelope-from <return@reactive-outpost.com>)'), 'from': ('"Grants-Notification" <infoz@reactive-outpost.com>',), 'subject': ('You may_be Eligible for Legitimate_Cash from_GovAgencies! ',), 'to': ('someone@yahoo.com',), 'precedence': ('junk',), 'in-reply-to': ('someone@yahoo.com',), 'content-type': ('text/html   ; charest="us-ascii"',), 'content-transfer-encoding': ('7bit',), 'date': ('\r\n       <HR>',)},
    attachments=[],
    from_values=EmailAddress(name='Grants-Notification', email='infoz@reactive-outpost.com'),
    to_values=(EmailAddress(name='', email='someone@yahoo.com'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='[skynet-help][60666] How are intermediate files handled in SkyNet?',
    from_='noreply@rubyforge.org',
    to=('noreply@rubyforge.org',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(2008, 9, 22, 15, 6, 28, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=72000))),
    date_str='Mon, 22 Sep 2008 15:06:28 -0400 (EDT)',
    text='Testing, testing, 123.',
    html='',
    headers={'delivered-to': ('xxx@xxx.com',), 'received': ('by 10.67.31.8 with SMTP id i8cs1195ugj;\r\n        Mon, 22 Sep 2008 13:45:18 -0700 (PDT)', 'by 10.100.207.5 with SMTP id e5mr3483815ang.104.1222110393505;\r\n        Mon, 22 Sep 2008 12:06:33 -0700 (PDT)', 'from rubyforge.org (rubyforge.org [205.234.109.19])\r\n        by mx.google.com with ESMTP id c2si899474ana.10.2008.09.22.12.06.28;\r\n        Mon, 22 Sep 2008 12:06:33 -0700 (PDT)', 'by rubyforge.org (Postfix, from userid 502)\r\n\tid 8FB1518581AC; Mon, 22 Sep 2008 15:06:28 -0400 (EDT)'), 'return-path': ('<noreply@rubyforge.org>',), 'received-spf': ('pass (google.com: best guess record for domain of noreply@rubyforge.org designates 205.234.109.19 as permitted sender) client-ip=205.234.109.19;',), 'authentication-results': ('mx.google.com; spf=pass (google.com: best guess record for domain of noreply@rubyforge.org designates 205.234.109.19 as permitted sender) smtp.mail=noreply@rubyforge.org',), 'to': ('noreply@rubyforge.org',), 'from': ('Sandy M. <noreply@rubyforge.org> ',), 'subject': ('[skynet-help][60666] How are intermediate files handled in SkyNet?',), 'content-type': ('text/plain; charset=UTF-8',), 'message-id': ('<20080922190628.8FB1518581AC@rubyforge.org>',), 'date': ('Mon, 22 Sep 2008 15:06:28 -0400 (EDT)',)},
    attachments=[],
    from_values=EmailAddress(name='Sandy M.', email='noreply@rubyforge.org'),
    to_values=(EmailAddress(name='', email='noreply@rubyforge.org'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='test',
    from_='xxxxxxx@docomo.ne.jp',
    to=('unknown@example.com',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(2014, 5, 28, 17, 18, 19, tzinfo=datetime.timezone(datetime.timedelta(seconds=32400))),
    date_str='Wed, 28 May 2014 17:18:19 +0900 (JST)',
    text='あいうえお\r\n\r\nこのメールはテスト用のメールです。\r\n\r\n今後ともよろしくお願い申し上げます！\r\n',
    html='',
    headers={'delivered-to': ('unknown@example.com',), 'date': ('Wed, 28 May 2014 17:18:19 +0900 (JST)',), 'from': ('xxxxxxx@docomo.ne.jp',), 'to': ('unknown@example.com',), 'subject': ('test',), 'message-id': ('<xxxxx@docomo.ne.jp>',), 'mime-version': ('1.0',), 'content-type': ('text/plain; charset="Shift_JIS"',), 'content-transfer-encoding': ('8bit',)},
    attachments=[],
    from_values=EmailAddress(name='', email='xxxxxxx@docomo.ne.jp'),
    to_values=(EmailAddress(name='', email='unknown@example.com'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Xxxxxx',
    from_='xxxxxx@xxxxxxxx.xxx',
    to=('xxxxxxx@xxxxxxxxxxx.xxx',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(2012, 4, 6, 1, 1, 1, tzinfo=datetime.timezone.utc),
    date_str='Fri, 6 Apr 2012 01:01:01 +0000',
    text='Test\r\n',
    html='<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/1999/REC-html401-19991224/strict.dtd"><html><head>\r\n<meta http-equiv="Content-Type" content="text/html; charset=utf-8">\r\n<title>Test</title>\r\n<body>\r\n<p>Test</p>\r\n</body>\r\n',
    headers={'received': ('from xxxx.xxxxxxx.xxx (127.0.0.1) by\r\n xxxx.xxxxxxxx.xxx (127.0.01) with Microsoft SMTP Server id\r\n 11.1.111.1; Thu, 5 Apr 2012 01:01:01 -0700',), 'message-id': ('<e4b473$b3jkq@xxxx.xxxx.xxxxxxxx.xxx>',), 'to': ('<xxxxxxx@xxxxxxxxxxx.xxx>',), 'subject': ('Xxxxxx',), 'date': ('Fri, 6 Apr 2012 01:01:01 +0000',), 'from': ('Xxxxx <xxxxxx@xxxxxxxx.xxx>',), 'x-mailer': ('PHP/5.2.6',), 'content-type': ('multipart/mixed;\r\n\tboundary="----=_NextPart_476c4fde88e507bb8028170e8cf47c73"',), 'mime-version': ('1.0',)},
    attachments=[
        dict(
            filename='LOGO.png',
            content_id='LOGO.png',
            content_disposition='attachment',
            content_type='application/octetstream',
            payload=b'H\xd2\x0f',
        ),
        ],
    from_values=EmailAddress(name='Xxxxx', email='xxxxxx@xxxxxxxx.xxx'),
    to_values=(EmailAddress(name='', email='xxxxxxx@xxxxxxxxxxx.xxx'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Another PDF with 🎉 Unicode chars in it 🍿',
    from_='xxxx@xxxx.com',
    to=('xxxx@xxxx.com', 'xxxx@xxxx.com'),
    cc=(),
    bcc=(),
    reply_to=('xxxx@xxxx.com',),
    date=datetime.datetime(2005, 5, 10, 11, 26, 39, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=64800))),
    date_str='Tue, 10 May 2005 11:26:39 -0600',
    text='Just attaching another PDF, here, to see what the message looks like,\r\nand to see if I can figure out what is going wrong here.\r\n',
    html='',
    headers={'return-path': ('<xxxx@xxxx.com>',), 'x-original-to': ('xxxx@xxxx.com',), 'delivered-to': ('xxxx@xxxx.com',), 'received': ('from localhost (localhost [127.0.0.1])\r\n\tby xxx.xxxxx.com (Postfix) with ESMTP id 50FD3A96F\r\n\tfor <xxxx@xxxx.com>; Tue, 10 May 2005 17:26:50 +0000 (GMT)', 'from xxx.xxxxx.com ([127.0.0.1])\r\n by localhost (xxx.xxxxx.com [127.0.0.1]) (amavisd-new, port 10024)\r\n with LMTP id 70060-03 for <xxxx@xxxx.com>;\r\n Tue, 10 May 2005 17:26:49 +0000 (GMT)', 'from xxx.xxxxx.com (xxx.xxxxx.com [69.36.39.150])\r\n\tby xxx.xxxxx.com (Postfix) with ESMTP id 8B957A94B\r\n\tfor <xxxx@xxxx.com>; Tue, 10 May 2005 17:26:48 +0000 (GMT)', 'from xxx.xxxxx.com (xxx.xxxxx.com [64.233.184.203])\r\n\tby xxx.xxxxx.com (Postfix) with ESMTP id 9972514824C\r\n\tfor <xxxx@xxxx.com>; Tue, 10 May 2005 12:26:40 -0500 (CDT)', 'by xxx.xxxxx.com with SMTP id 68so1694448wri\r\n        for <xxxx@xxxx.com>; Tue, 10 May 2005 10:26:40 -0700 (PDT)', 'by 10.54.96.19 with SMTP id t19mr621017wrb;\r\n        Tue, 10 May 2005 10:26:39 -0700 (PDT)', 'by 10.54.110.5 with HTTP; Tue, 10 May 2005 10:26:39 -0700 (PDT)'), 'domainkey-signature': ('a=rsa-sha1; q=dns; c=nofws;\r\n        s=beta; d=xxxxx.com;\r\n        h=received:message-id:date:from:reply-to:to:subject:mime-version:content-type;\r\n        b=g8ZO5ttS6GPEMAz9WxrRk9+9IXBUfQIYsZLL6T88+ECbsXqGIgfGtzJJFn6o9CE3/HMrrIGkN5AisxVFTGXWxWci5YA/7PTVWwPOhJff5BRYQDVNgRKqMl/SMttNrrRElsGJjnD1UyQ/5kQmcBxq2PuZI5Zc47u6CILcuoBcM+A=',), 'message-id': ('<xxxx@xxxx.com>',), 'date': ('Tue, 10 May 2005 11:26:39 -0600',), 'from': ('Test Tester <xxxx@xxxx.com>',), 'reply-to': ('Test Tester <xxxx@xxxx.com>',), 'to': ('xxxx@xxxx.com, xxxx@xxxx.com',), 'subject': ('Another PDF with \udcf0\udc9f\udc8e\udc89 Unicode chars in it \udcf0\udc9f\udc8d\udcbf',), 'mime-version': ('1.0',), 'content-type': ('multipart/mixed; \r\n\tboundary="----=_Part_2192_32400445.1115745999735"',), 'x-virus-scanned': ('amavisd-new at textdrive.com',)},
    attachments=[
        dict(
            filename='broken.pdf',
            content_id='',
            content_disposition='attachment',
            content_type='application/pdf',
            payload=b'%PDF-1.4\r\n%\xe4\xf6\xdc\xdf\r\n1 0 obj\r\n<< /Length 2 0 R\r\n   /Filter /FlateDecode\r\n>>\r\nstream\r\nx\x9c\xbdZ\xdd\x8a%\xb9\r\xbeo\xe8w\xa8\xeb\x85\x9cX\x96\x7faXHv\xa7\xef\x07\x06\xf2\x02\xc9&\x84\xc9\xc2\xeeM^?\xd6\'\xc9\xf6\xa9\xea\xd3\xd3iH\x18\xa6\xbb\xbe\xb2-K\xb2\xfe\xac\xeap\xfc\xfb\xf9\xe9\xb7#\x1c\x7f\x087:\n\xc5\xf1\xb3v\xf9\xf9\xfb\xdf\x8e\xbf\xfcp\xfc\xfa\xfc\x14n\xad\xb7\xc0\xc7\xf9\xf7\xef\x7f\x7f~\xe2r\x94\x9en\xe5\xf8\xd7\xf3S\xae\x0e\xbe\x1dx\xae\x01\xcf|\xffh3\xfe\xf1\xfc\xf4\xcb\x0f \xd0\xe7\xea\xeeKk\xd4\xc9\xfe\xbbo+\xbe\x1c\xbf\x8dW\x83A&\xbe\xf5\x83J\x1c\xff\xe9\xc6;\xc35\xf5@\xc7\xf9\xb70\\\xf9\xe0XoM\xb6\xacy\xacb\x0e\x83v-\xe3\x153\x0f\xb2\x03\xb4[\x1d \x83\xcf\x16ni\x80v\x13V\x1a\xcb\xb4\x14\xc7\xcfo\xcfO\xad\xc8P\xca2P\x07+\x9c\xaa.i\xe3\x17\xe78F1"@\x85\x1e+\x06\xe5\\\xc7\xbe\x02\xc6c7Ry\xc8d\x0b\xe41\xe9\x0cy,\xba\xb3<\xd6\xb1z<\xa6\x9b\x80\xae\xb3\x01\xaa\xc8\x0f2"Q\x8d\xb7\xac\x9b\r\xf6*+\x00O5\xe9\xa2.\xea[ \x01\xd4\x05\xb2\xe8a\x90s\x94\x16\x05c\xa7a\xa32\xa4\x9e\xc0\x84\xd75\r\xbb\x8e\xb3\x1eji \xd6\xb3\xc8\xde"\xd6\x1b`\x88i A\xf9]v\xe3\x96\x15D\x80\x86m\xbaX(w6Q!C\x97\xa34\xf5\xa7\x10U\x06!\x97\x02+\x90\x13K!+\xd7\x84iE\xd7\x08\xb9\x14p\xb0\xc3\x16d\xa0cI\x95W\x89\x08K*(\x0f\xb7`\x05y\x00\xc6\xfa*G\x9a\xa8BP\x98R\x8aAO\x13\xd6\x94b\xda(D\xd5\x8e\x02\x0e\xba\xa8`QWb2I9\xabl\xcb;\x88\xf1"%\xcaK\xb1)3"mb\xbc\x1fS\xe0\x12\xfa\x98\x82\xce\x06\x99\x04\xab\x122@jX\x06\x8a\xb2!\x8aO\xa9\xe1\x94\r\xf4M\xc4LS\xc0\x1cM[\xf2\x9au\x97\xfd\x11sX%}\x0b4\x00\x15\xaf\xca\x86Y\xcdO\x15\x9c\xf5\xf0UW\x0e\xf4\x11,\xca1\th\xee\x9e\x06\x86Q\xc8\xa1\xa5\xac\xaa\x18\xa0\xec\xa0\x03\xc0F#807tP\xd7\x9a.\x8a\x01\xb9\x89\xd6P\x7f\x1d\x94\xe06\xf6\n\xa8\x8b;E\x87\x01\x9a2\x94h\x82\x02\xa8g\x88\xd4#\x164\x0fJI\xa3\xc1\xf3S\x81\x0e\x8c\xd4\x88~yj7\xeb\x01f\x8c\x8cC%\x98\x86P\x18\x96\xb0\x0c\x91\xc5}\xc4zA\x8e\x8b9\x06#\xde\x8e\x97\xdc\xd5e0"\xbe)\x14F\x14l\x1e\x1d\x84\xdc\x98V2\x94\x93d)\xe7\xa2z\xcb\x84\xc0\xa8v\n\xcdr\n8\xbb"T%\xce\xaa\x9d[,\x9e\xb1\x9d\xd4\xfbk\xd1\x8c"\xb0#\x98\xc8\x86\xd4\xc1X\xd5\xe3\x10T4\xb6\xe0\xb9#\xb6`{\xa3\xa2p\x0c&C\x1dH\x8e\xdb#\x0fu\x02J\xb6\x01ILQa\x85L\xc0\x0ejh\xd4:\xf6P\x0b\x12$cjB\xa4\xc1h\xfc\x8c\x0buR\xc7\xb3\xa9\xddw\x04\xd1\xae\n\x15n\xf2\xd4\xf5\xe0t\x1b\x81\x0c\x9d\xd5tL\xda1\x1d\xbbw$\x15\xb0+\xa8a\xbfx\x87|;E\xca\x89\x01\xdfM\x88\xa4@S\x9db\x02u\xee.a\xcf\xf5\x92\x10\xdbH\x89\x10\xa2\x93\xba\x95\xca\x9a\x98`n\xd4\xe4\x84\xdc\xdeH=+\x19_M\x02\x91!\xd1\x8a,\xb1\xe8t\x08J\x1b\x12\x1d%M\xb3\x07U\xb1\xa3\x94H\x05\xaa\xf5\xa6!\x0e\xd1\x83j\x81\xb9kyA\x1aF-\xfeQe\x04[uR\xaa\xd8\x9f5mR\x95\x10\x9c\xb8\x99z\x8b\x8a\x81\xfdJ\x85\x10U\x89\x14d\x13\x17\xa9$,\xd3\xc0I\x85\r\xa9HE\xb2\xc4\x1a\xdc4\x81\xfaDH\xeaH\x00_\xcd\x9e\x93\xf3qP\x86\xf3\xab4\x83`\xeeK\'x\xd6\xe8M\x19\xb1 i*\xd6\x11s\x91\x12\xb6\xf0',
        ),
        ],
    from_values=EmailAddress(name='Test Tester', email='xxxx@xxxx.com'),
    to_values=(EmailAddress(name='', email='xxxx@xxxx.com'), EmailAddress(name='', email='xxxx@xxxx.com')),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(EmailAddress(name='Test Tester', email='xxxx@xxxx.com'),),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Fwd: Signed email causes file attachments',
    from_='xxxxxxxxx.xxxxxxx@gmail.com',
    to=('xxxxx@xxxxxxxxx.com',),
    cc=(),
    bcc=(),
    reply_to=('xxxxxxxxx.xxxxxxx@gmail.com',),
    date=datetime.datetime(2005, 5, 8, 14, 9, 11, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=68400))),
    date_str='Sun, 8 May 2005 14:09:11 -0500',
    text='We should not include these files or vcards as attachments.\r\n\r\n---------- Forwarded message ----------\r\nFrom: xxxxx xxxxxx <xxxxxxxx@xxx.com>\r\nDate: May 8, 2005 1:17 PM\r\nSubject: Signed email causes file attachments\r\nTo: xxxxxxx@xxxxxxxxxx.com\r\n\r\n\r\nHi,\r\n\r\nJust started to use my xxxxxxxx account (to set-up a GTD system,\r\nnatch) and noticed that when I send content via email the signature/\r\ncertificate from my email account gets added as a file (e.g.\r\n"smime.p7s").\r\n\r\nObviously I can uncheck the signature option in the Mail compose\r\nwindow but how often will I remember to do that?\r\n\r\nIs there any way these kind of files could be ignored, e.g. via some\r\nsort of exclusions list?\r\n',
    html='',
    headers={'return-path': ('<xxxxxxxxx.xxxxxxx@gmail.com>',), 'x-original-to': ('xxxxx@xxxxx.xxxxxxxxx.com',), 'delivered-to': ('xxxxx@xxxxx.xxxxxxxxx.com',), 'received': ('from localhost (localhost [127.0.0.1])\r\n\tby xxxxx.xxxxxxxxx.com (Postfix) with ESMTP id 06C9DA98D\r\n\tfor <xxxxx@xxxxx.xxxxxxxxx.com>; Sun,  8 May 2005 19:09:13 +0000 (GMT)', 'from xxxxx.xxxxxxxxx.com ([127.0.0.1])\r\n by localhost (xxxxx.xxxxxxxxx.com [127.0.0.1]) (amavisd-new, port 10024)\r\n with LMTP id 88783-08 for <xxxxx@xxxxx.xxxxxxxxx.com>;\r\n Sun,  8 May 2005 19:09:12 +0000 (GMT)', 'from xxxxxxx.xxxxxxxxx.com (xxxxxxx.xxxxxxxxx.com [69.36.39.150])\r\n\tby xxxxx.xxxxxxxxx.com (Postfix) with ESMTP id 10D8BA960\r\n\tfor <xxxxx@xxxxxxxxx.org>; Sun,  8 May 2005 19:09:12 +0000 (GMT)', 'from zproxy.gmail.com (zproxy.gmail.com [64.233.162.199])\r\n\tby xxxxxxx.xxxxxxxxx.com (Postfix) with ESMTP id 9EBC4148EAB\r\n\tfor <xxxxx@xxxxxxxxx.com>; Sun,  8 May 2005 14:09:11 -0500 (CDT)', 'by zproxy.gmail.com with SMTP id 13so1233405nzp\r\n        for <xxxxx@xxxxxxxxx.com>; Sun, 08 May 2005 12:09:11 -0700 (PDT)', 'by 10.36.10.16 with SMTP id 16mr1012493nzj;\r\n        Sun, 08 May 2005 12:09:11 -0700 (PDT)', 'by 10.36.5.10 with HTTP; Sun, 8 May 2005 12:09:11 -0700 (PDT)'), 'domainkey-signature': ('a=rsa-sha1; q=dns; c=nofws;\r\n        s=beta; d=gmail.com;\r\n        h=received:message-id:date:from:reply-to:to:subject:in-reply-to:mime-version:content-type:references;\r\n        b=cid1mzGEFa3gtRa06oSrrEYfKca2CTKu9sLMkWxjbvCsWMtp9RGEILjUz0L5RySdH5iO661LyNUoHRFQIa57bylAbXM3g2DTEIIKmuASDG3x3rIQ4sHAKpNxP7Pul+mgTaOKBv+spcH7af++QEJ36gHFXD2O/kx9RePs3JNf/K8=',), 'message-id': ('<e85734b90505081209eaaa17b@mail.gmail.com>',), 'date': ('Sun, 8 May 2005 14:09:11 -0500',), 'from': ('xxxxxxxxx xxxxxxx <xxxxxxxxx.xxxxxxx@gmail.com>',), 'reply-to': ('xxxxxxxxx xxxxxxx <xxxxxxxxx.xxxxxxx@gmail.com>',), 'to': ('xxxxx xxxx <xxxxx@xxxxxxxxx.com>',), 'subject': ('Fwd: Signed email causes file attachments',), 'in-reply-to': ('<F6E2D0B4-CC35-4A91-BA4C-C7C712B10C13@mac.com>',), 'mime-version': ('1.0',), 'content-type': ('multipart/mixed; \r\n\tboundary="----=_Part_5028_7368284.1115579351471"',), 'references': ('<F6E2D0B4-CC35-4A91-BA4C-C7C712B10C13@mac.com>',)},
    attachments=[
        dict(
            filename='smime.p7s',
            content_id='',
            content_disposition='attachment',
            content_type='application/pkcs7-signature',
            payload=b'0\x80\x06\t*\x86H\x86\xf7\r\x01\x07\x02\xa0\x800\x80\x02\x01\x011\x0b0\t\x06\x05+\x0e\x03\x02\x1a\x05\x000\x80\x06\t*\x86H\x86\xf7\r\x01\x07\x01\x00\x00\xa0\x82\x06\x140\x82\x02\xcd0\x82\x026\xa0\x03\x02\x01\x02\x02\x03\x0e\\\xf90\r\x06\t*\x86H\x86\xf7\r\x01\x01\x04\x05\x000b1\x0b0\t\x06\x03U\x04\x06\x13\x02ZA1%0#\x06\x03U\x04\n\x13\x1cThawte Consulting (Pty) Ltd.1,0*\x06\x03U\x04\x03\x13#Thawte Personal Freemail Issuing CA0\x1e\x17\r050329093910Z\x17\r060329093910Z0B1\x1f0\x1d\x06\x03U\x04\x03\x13\x16Thawte Freemail Member1\x1f0\x1d\x06\t*\x86H\x86\xf7\r\x01\t\x01\x16\x10smhaunch@mac.com0\x82\x01"0\r\x06\t*\x86H\x86\xf7\r\x01\x01\x01\x05\x00\x03\x82\x01\x0f\x000\x82\x01\n\x02\x82\x01\x01\x00\x9f\xdd\x1d>\xc6\x12\xdc\xb8\xdf1\x8d\xb5\xd4\xe4\x98\xac4\x0b\xcf\x03X>P\x0b\xef\xef\xf4\\\x0f\xa4w/?\xad\x19\xf2\x10qF\xc2\x13B\x0eh4\x07\xaaq\x0b\xbc\xf7\xc7\x12C\xff\xc1\x9f\t\xdf\x88aE\rQ\x05y\x9b\xd3$\xc5\xf3\xfd\xa55WeR\x18-\xa0p\xa3\xccR\xdc\r\x1a\xd4\xb5\xdejW&\x94F\xc9\x89\xb9\x8a\x90F\xa8]\xc8\xb72\x1a\xf2.\nZk\xe2\xa4\xfe\xc1\xf4\xd9#Z\xb43\xb5\xbd-\xbcl\xfb"m\x9a\\s\xa7^\x16\xb9Z\x85&\'/\xe3\xd6\xe7\x89\x83La\xc8p#v}\xbc\x7fc\xaa\xac\xa7:\xa6\xb4\xa6\x97\xae\xfe\xf94\x1bn\xcb\xd7\x01\xe8\xac\xd4\xe2=\xb1]\xb4\xe4\x03\x0c\xf7\xa5\x14\xa0\x84\x92Z\x03\x07i\xfb""\xbc\x00\xf7\xbe\xbd$$M\xe9\xf8L\xf7\xe0s!\xdfq\x17\x12\x91hY\xc3~0!\x10d?V\x9eaU\x88\xca\xef~\xf3\x17,eEA\xf0\x00p-:\xd1\xe1\x85I\x12ue\x0fTU\x02\x03\x01\x00\x01\xa3-0+0\x1b\x06\x03U\x1d\x11\x04\x140\x12\x81\x10smhaunch@mac.com0\x0c\x06\x03U\x1d\x13\x01\x01\xff\x04\x020\x000\r\x06\t*\x86H\x86\xf7\r\x01\x01\x04\x05\x00\x03\x81\x81\x00@\xca\xe0\xd6}\xa9]U\xadx\xfe\xc1\x06?\x8f\x93u\x1fb\xd6\xee\x1d\xbe6\xb8w\x0b&7\xe3\x9d\x19G\xec\x0cgK\n\xdd/q\xc4\x0fm9\xc3p\xaa\xf1>\xed\xcd\\H\x8d\x14K;\xf9c\xabA\x9eu \x85\x06L\xbby\x8a5>\xb5\xe1\xce\xd1\x87\t4\x81\x86\xc8\x96v,\x8b[\x12\xa5;\x11\x80\xc0\x97?\x94\xc3\'\xc2\xa2\xcev\xb4\x1c\xa0_\xd8\x81\xb8\xdeiANA\xb5!\xf7\x8c=T3iY\x96\x02g\x070\x82\x03?0\x82\x02\xa8\xa0\x03\x02\x01\x02\x02\x01\r0\r\x06\t*\x86H\x86\xf7\r\x01\x01\x05\x05\x000\x81\xd11\x0b0\t\x06\x03U\x04\x06\x13\x02ZA1\x150\x13\x06\x03U\x04\x08\x13\x0cWestern Cape1\x120\x10\x06\x03U\x04\x07\x13\tCape Town1\x1a0\x18\x06\x03U\x04\n\x13\x11Thawte Consulting1(0&\x06\x03U\x04\x0b\x13\x1fCertification Services Division1$0"\x06\x03U\x04\x03\x13\x1bThawte Personal Freemail CA1+0)\x06\t*\x86H\x86\xf7\r\x01\t\x01\x16\x1cpersonal-freemail@thawte.com0\x1e\x17\r030717000000Z\x17\r130716235959Z0b1\x0b0\t\x06\x03U\x04\x06\x13\x02ZA1%0#\x06\x03U\x04\n\x13\x1cThawte Consulting (Pty) Ltd.1,0*\x06\x03U\x04\x03\x13#Thawte Personal Freemail Issuing CA0\x81\x9f0\r\x06\t*\x86H\x86\xf7\r\x01\x01\x01\x05\x00\x03\x81\x8d\x000\x81\x89\x02\x81\x81\x00\xc4\xa6<UsU\xfbN\xb9\xca\x99Z\x1eh\xc0u\x04p\x9d\xdf\xe9\xff\xa3\x1e\xec\xbd\xcd\xf5[\xf2\x1av\xbd\x7f\x0c:a\xf2\xbfQ\xce\x01\xd4\xe5P\n0\xd7\x02cZ,\x89\x15p\x8e\xdd\xc9\xf0+\x85Z\xaa?qV\xcb\xaf<\x0b\x07\xe7\xf1\x1f\x916$*\x13\xcf+\xd5\xf3\x82w=\x03\xbe+\xfe\xbb\x18>\x07\xbf@\x80\x02d\xd7\xa7\xa6\xbb\x9fe\xd1\xc5*T\x85\x0fH\x04\x7f\xa7\xb6\xd1<a\x04@\x1ed\x19r`\xb7\xfb\x02\x03\x01\x00\x01\xa3\x81\x940\x81\x910\x12\x06\x03U\x1d\x13\x01\x01\xff\x04\x080\x06\x01\x01\xff\x02\x01\x000C\x06\x03U\x1d\x1f\x04<0:08\xa06\xa04\x862http://crl.thawte.com/ThawtePersonalFreemailCA.crl0\x0b\x06\x03U\x1d\x0f\x04\x04\x03\x02\x01\x060)\x06\x03U\x1d\x11\x04"0 \xa4\x1e0\x1c1\x1a0\x18\x06\x03U\x04\x03\x13\x11PrivateLabel2-1380\r\x06\t*\x86H\x86\xf7\r\x01\x01\x05\x05\x00\x03\x81\x81\x00H\x8c\xd1P\x83\xea\x0b.\xcc\r\xa3f\xacg\x0f\x7f\xaf\xac\xbe\xc2\x17\xa1C\x96\x94\x9d\x7fL!\xb8\xf86\x1f\xaa-\x9f6/\xc0\xf4\x1cP \x93p<\xfd\xad\xe1ab\xc3\xd9:\x19~\x84\xb1\x99\x1b\x00\xc5\x1a\x0b\x82t\x9e%P\x94b\xc7\xdb\'qW%\x8d\xdd\xa9\x9c9\x8e\x8c Oe_\x95\xda\xf7\xf7\x87\xd6\xc6\x08N\xae\xf6\xea4\xe5\x10\x1a[5Mw\xe3V!x\x82\xdc!\x195\xde$\xb1\xd3\x1dF\xff]_eO1\x82\x02\xe70\x82\x02\xe3\x02\x01\x010i0b1\x0b0\t\x06\x03U\x04\x06\x13\x02ZA1%0#\x06\x03U\x04\n\x13\x1cThawte Consulting (Pty) Ltd.1,0*\x06\x03U\x04\x03\x13#Thawte Personal Freemail Issuing CA\x02\x03\x0e\\\xf90\t\x06\x05+\x0e\x03\x02\x1a\x05\x00\xa0\x82\x01S0\x18\x06\t*\x86H\x86\xf7\r\x01\t\x031\x0b\x06\t*\x86H\x86\xf7\r\x01\x07\x010\x1c\x06\t*\x86H\x86\xf7\r\x01\t\x051\x0f\x17\r050508181746Z0#\x06\t*\x86H\x86\xf7\r\x01\t\x041\x16\x04\x14\x12\x90oc\xeb\xe8A\xd2\x92\xa9}_m\n/\xe2?\x9fl50x\x06\t+\x06\x01\x04\x01\x827\x10\x041k0i0b1\x0b0\t\x06\x03U\x04\x06\x13\x02ZA1%0#\x06\x03U\x04\n\x13\x1cThawte Consulting (Pty) Ltd.1,0*\x06\x03U\x04\x03\x13#Thawte Personal Freemail Issuing CA\x02\x03\x0e\\\xf90z\x06\x0b*\x86H\x86\xf7\r\x01\t\x10\x02\x0b1k\xa0i0b1\x0b0\t\x06\x03U\x04\x06\x13\x02ZA1%0#\x06\x03U\x04\n\x13\x1cThawte Consulting (Pty) Ltd.1,0*\x06\x03U\x04\x03\x13#Thawte Personal Freemail Issuing CA\x02\x03\x0e\\\xf90\r\x06\t*\x86H\x86\xf7\r\x01\x01\x01\x05\x00\x04\x82\x01\x00&\xd4g\x85\xed\xd5\x9f2\xfa\xd6\xf3#\x0f\x8eHD\xf9\x1f\x03\xd4;"\n\x85\x92\n\x9f\xb9\x80\x04&\xeeW\n\xed]\xca\xad\x98y\x86\x8c\x1f\xa4\x8d\xd3\x98&Tm\xb6\x8c\xc4\xe1\xfe\xed\xa2\x91*\x91^\x9b\x1a\x01c\x94<\xaep\xa4n\x98?\xfb\xef\xfe0\x8d5O\xafa\x17\xfa\xe02j\xc6r\xbb\xf6|\x862\xf0F\x80D\xb1\xb4\xc5EEI\x91\xd2?\xe3PI\x8c\xf4M9\xa1\xe1\xc0\x04Hs3cr@\x9cs\xa8RK\x8f\xca_\x11^\xb8\xa6c\\\xe7\xd2W\x1e1ypy\x94h\xba#\xc6\xb8\xf3e\xd6\x14\n\xc3\xc3\xfe\x1a\x13\x82\xe6\x82\xe53\xbdT\xb5+g\xaeY7?\xd8*_\x9b\xfbN>\xc7\xc7N{\xa1W\xd8\xf0S\x1e\xbe<F\xc1M\xc4+\x94\xdc\xccw\xb3\x1d\xb5\x96\x81<\xae\x9b\xd9ve\x06\xd4B\xc0\xc9\xc5)\xe2\x0fpL\xe3\xa0\xb5U\xc6\xc3,\xf6\xa8\xb4\x06t}6\x0bf,\xd0~naqa\x1b}\x85s\x91,\xcb\x00\x00\x00\x00\x00\x00',
        ),
        ],
    from_values=EmailAddress(name='xxxxxxxxx xxxxxxx', email='xxxxxxxxx.xxxxxxx@gmail.com'),
    to_values=(EmailAddress(name='xxxxx xxxx', email='xxxxx@xxxxxxxxx.com'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(EmailAddress(name='xxxxxxxxx xxxxxxx', email='xxxxxxxxx.xxxxxxx@gmail.com'),),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='статус',
    from_='i.kor@company.ru',
    to=('jessica.schmidt@uni.de', 'я你Rabea.Bartölke@uni.de'),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(2017, 10, 12, 9, 41, 56, tzinfo=datetime.timezone(datetime.timedelta(seconds=18000))),
    date_str='Thu, 12 Oct 2017 09:41:56 +0500',
    text='\r\nНовый заказ №28922 http://group.company.ru/ru/order/28922/process/\r\nСоздал: \r\nКлиент Ковчег (Гусев Дмитрий)\r\n\r\nСегменты:\r\n\r\n- Москва - Тель-Авив, some-889, 15.03.2018, эконом: (15 взр.)\r\n\r\n- Тель-Авив - Москва, some-890, 22.03.2018, эконом: (15 взр.)',
    html='\r\n\r\n    <!DOCTYPE html PUBLIC \'-//W3C//DTD XHTML 1.0 Strict//EN\' \'http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\'>\r\n    <html xmlns=\'http://www.w3.org/1999/xhtml\' lang=\'ru-ru\'\r\n          xml:lang=\'en-us\'>\r\n    <head>\r\n        <meta content="text/html; charset=utf-8" http-equiv="Content-Type">\r\n        \r\n    </head>\r\n\r\n    <body id=\'body\'>\r\n    \r\n    \r\n        \r\n        <a href="http://group.company.ru/ru/order/28922/process/">\r\n            \r\n            Новый заказ №28922\r\n        </a>\r\n\r\n    </body>\r\n    </html>\r\n\r\n',
    headers={'subject': ('=?UTF-8?B?0YHRgtCw0YLRg9GB?=',), 'to': ('Jessica Schmidt <jessica.schmidt@uni.de>,\r\n\t=?iso-8859-1?Q?Rabea=2EBart=F6lke=40uni=2Ede?= <\udcd1\udc8f\udce4\udcbd\udca0Rabea.Bart\udcc3\udcb6lke@uni.de>',), 'from': ('i.kor@company.ru',), 'message-id': ('<2405271c-86ac-0a65-e50c-d1ebccfcc644@company.ru>',), 'date': ('Thu, 12 Oct 2017 09:41:56 +0500',), 'mime-version': ('1.0',), 'in-reply-to': ('<20171011085432.15374.20485@web.hades.company>',), 'content-type': ('multipart/mixed;\r\n boundary="------------BF90926EC9DF73443A6B8F28"',), 'content-language': ('ru',)},
    attachments=[
        dict(
            filename='',
            content_id='',
            content_disposition='attachment',
            content_type='message/rfc822',
            payload=b'Content-Type: multipart/alternative;\n boundary="===============3693132879591888836=="\nMIME-Version: 1.0\nSubject: =?UTF-8?B?0YHRgtCw0YLRg9GB?=    \nFrom: group@company.ru\nTo: group@company.ru\nDate: Wed, 11 Oct 2017 08:54:32 -0000\nMessage-ID: <20171011085432.15374.20485@web.hades.company>\n\n--===============3693132879591888836==\nContent-Type: text/plain; charset="utf-8"\nMIME-Version: 1.0\nContent-Transfer-Encoding: quoted-printable\n\n=D0=9D=D0=BE=D0=B2=D1=8B=D0=B9 =D0=B7=D0=B0=D0=BA=D0=B0=D0=B7 =E2=84=9628=\n922 http://group.company.ru/ru/order/28922/process/\n=D0=A1=D0=BE=D0=B7=D0=B4=D0=B0=D0=BB:=20\n=D0=9A=D0=BB=D0=B8=D0=B5=D0=BD=D1=82 =D0=9A=D0=BE=D0=B2=D1=87=D0=B5=D0=B3=\n (=D0=93=D1=83=D1=81=D0=B5=D0=B2 =D0=94=D0=BC=D0=B8=D1=82=D1=80=D0=B8=D0=B9=\n)\n\n=D0=A1=D0=B5=D0=B3=D0=BC=D0=B5=D0=BD=D1=82=D1=8B:\n\n- =D0=9C=D0=BE=D1=81=D0=BA=D0=B2=D0=B0 - =D0=A2=D0=B5=D0=BB=D1=8C-=D0=90=D0=\n=B2=D0=B8=D0=B2, some-889, 15.03.2018, =D1=8D=D0=BA=D0=BE=D0=BD=D0=BE=D0=BC=\n: (15 =D0=B2=D0=B7=D1=80.)\n\n- =D0=A2=D0=B5=D0=BB=D1=8C-=D0=90=D0=B2=D0=B8=D0=B2 - =D0=9C=D0=BE=D1=81=D0=\n=BA=D0=B2=D0=B0, some-890, 22.03.2018, =D1=8D=D0=BA=D0=BE=D0=BD=D0=BE=D0=BC=\n: (15 =D0=B2=D0=B7=D1=80.)\n--===============3693132879591888836==\nContent-Type: text/html; charset="utf-8"\nMIME-Version: 1.0\nContent-Transfer-Encoding: quoted-printable\n\n\n\n    <!DOCTYPE html PUBLIC \'-//W3C//DTD XHTML 1.0 Strict//EN\' \'http://www.=\nw3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\'>\n    <html xmlns=3D\'http://www.w3.org/1999/xhtml\' lang=3D\'ru-ru\'\n          xml:lang=3D\'en-us\'>\n    <head>\n        <meta content=3D"text/html; charset=3DUTF-8" http-equiv=3D"Conten=\nt-Type">\n       =20\n    </head>\n\n    <body id=3D\'body\'>\n   =20\n   =20\n       =20\n        <a href=3D"http://group.company.ru/ru/order/28922/process/">\n           =20\n            =D0=9D=D0=BE=D0=B2=D1=8B=D0=B9 =D0=B7=D0=B0=D0=BA=D0=B0=D0=B7=\n =E2=84=9628922\n        </a>\n\n    </body>\n    </html>\n\n\n--===============3693132879591888836==--\n',
        ),
        ],
    from_values=EmailAddress(name='', email='i.kor@company.ru'),
    to_values=(EmailAddress(name='Jessica Schmidt', email='jessica.schmidt@uni.de'), EmailAddress(name='Rabea.Bartölke@uni.de', email='я你Rabea.Bartölke@uni.de')),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Filth',
    from_='xxx@xxxx.xxx',
    to=('xxx@xxxx.xxx',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(2005, 5, 8, 12, 30, 8, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=68400))),
    date_str='Sun, 8 May 2005 12:30:08 -0500',
    text="Some text\r\n\r\n--\r\nThis Orange Multi Media Message was sent wirefree from an Orange\r\nMMS phone. If you would like to reply, please text or phone the\r\nsender directly by using the phone number listed in the sender's\r\naddress. To learn more about Orange's Multi Media Messaging\r\nService, find us on the Web at xxx.xxxx.xxx.uk/mms\r\n\r\n\r\n--mimepart_427e4cb4ca329_133ae40413c81ef-\r\n",
    html='',
    headers={'return-path': ('<xxx@xxxx.xxx>',), 'received': ('from xxx.xxxx.xxx by xxx.xxxx.xxx with ESMTP id 6AAEE3B4D23 for <xxx@xxxx.xxx>; Sun, 8 May 2005 12:30:23 -0500', 'from xxx.xxxx.xxx by xxx.xxxx.xxx with ESMTP id j48HUC213279 for <xxx@xxxx.xxx>; Sun, 8 May 2005 12:30:13 -0500', 'from conversion-xxx.xxxx.xxx.net by xxx.xxxx.xxx id <0IG600901LQ64I@xxx.xxxx.xxx> for <xxx@xxxx.xxx>; Sun, 8 May 2005 12:30:12 -0500', 'from agw1 by xxx.xxxx.xxx with ESMTP id <0IG600JFYLYCAxxx@xxxx.xxx> for <xxx@xxxx.xxx>; Sun, 8 May 2005 12:30:12 -0500'), 'date': ('Sun, 8 May 2005 12:30:08 -0500',), 'from': ('xxx@xxxx.xxx',), 'to': ('xxx@xxxx.xxx',), 'message-id': ('<7864245.1115573412626.JavaMxxx@xxxx.xxx>',), 'subject': ('Filth',), 'mime-version': ('1.0',), 'content-type': ('multipart/mixed; boundary=mimepart_427e4cb4ca329_133ae40413c81ef',), 'x-mms-priority': ('1',), 'x-mms-transaction-id': ('3198421808-0',), 'x-mms-message-type': ('0',), 'x-mms-sender-visibility': ('1',), 'x-mms-read-reply': ('1',), 'x-original-to': ('xxx@xxxx.xxx',), 'x-mms-message-class': ('0',), 'x-mms-delivery-report': ('0',), 'x-mms-mms-version': ('16',), 'delivered-to': ('xxx@xxxx.xxx',), 'x-nokia-ag-version': ('2.0',)},
    attachments=[],
    from_values=EmailAddress(name='', email='xxx@xxxx.xxx'),
    to_values=(EmailAddress(name='', email='xxx@xxxx.xxx'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='TEST',
    from_='',
    to=(),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(1900, 1, 1, 0, 0),
    date_str='',
    text='TEST\r\n',
    html='',
    headers={'subject': ('=?NONE?B?VEVTVA=?=',)},
    attachments=[],
    from_values=None,
    to_values=(),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import unittest

from tests.utils import MailboxTestCase


class IdleTest(MailboxTestCase):

    def test_idle(self):
        for mailbox_name, mailbox in self.mailbox_set.items():
            if mailbox.mailbox_name in ('MAIL_RU', 'YAHOO'):
                continue
            responses1 = mailbox.idle.wait(timeout=0.5)
            self.assertIs(type(responses1), list)

            mailbox.idle.start()
            responses2 = mailbox.idle.poll(0.5)
            mailbox.idle.stop()
            self.assertIs(type(responses2), list)

            self.assertEqual(len(tuple(mailbox.fetch(limit=1))), 1)


if __name__ == "__main__":
    unittest.main()



from imap_tools import MailMessage

with open('.../attachment_2_base64.eml', 'rb') as f:
    bytes_data = f.read()
msg = MailMessage.from_bytes(bytes_data)
print(msg.date_str, msg.subject)
for i, att in msg.attachments:
    print('-', att.filename, att.content_type, len(att.payload))



import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Daily',
    from_='status@sender.com',
    to=('my.name@domain.com', 'other.name@domain.com'),
    cc=('third.name@domain.com', 'quoted-mailing-list-one@domain.com', 'quoted-mailing-list-two@domain.com'),
    bcc=('my.name@domain.com', 'list1-one-name@domain.com', 'list2-second-name@domain.com'),
    reply_to=(),
    date=datetime.datetime(2020, 11, 1, 14, 49, 7, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=57600))),
    date_str='Mon, 01 Nov 2020 14:49:07 -0800 (PST)',
    text='Daily Data: D09.ZPH (Averaged data)\nEmail generated: 10/11/2020 00:04:03.765\nEmail sent: 10/11/2020 00:49:03.125',
    html='',
    headers={'message-id': ('<5fa9c763>',), 'date': ('Mon, 01 Nov 2020 14:49:07 -0800 (PST)',), 'mime-version': ('1.0',), 'from': ('"Sender" <status@sender.com>',), 'to': ('My Name <my.name@domain.com>, Other Name\r\n    <other.name@domain.com>',), 'cc': ('Third Name <third.name@domain.com>, "Quoted Mailing List\r\n One" <quoted-mailing-list-one@domain.com>, "Quoted\r\n Mailing List Two" <quoted-mailing-list-two@domain.com>',), 'bcc': ('My Name <my.name@domain.com>, Mailing List One - One Name\r\n    <list1-one-name@domain.com>, Mailing List Two - Second Name\r\n    <list2-second-name@domain.com>',), 'subject': ('Daily',), 'content-type': ('multipart/mixed; boundary=--boundary_20_d4727d16-8454-4fa4-9da0-950a95b2c962',)},
    attachments=[
        dict(
            filename='D09.ZPH.txt',
            content_id='',
            content_disposition='',
            content_type='application/octet-stream',
            payload=b'12',
        ),
        ],
    from_values=EmailAddress(name='Sender', email='status@sender.com'),
    to_values=(EmailAddress(name='My Name', email='my.name@domain.com'), EmailAddress(name='Other Name', email='other.name@domain.com')),
    cc_values=(EmailAddress(name='Third Name', email='third.name@domain.com'), EmailAddress(name='Quoted Mailing List One', email='quoted-mailing-list-one@domain.com'), EmailAddress(name='Quoted Mailing List Two', email='quoted-mailing-list-two@domain.com')),
    bcc_values=(EmailAddress(name='My Name', email='my.name@domain.com'), EmailAddress(name='Mailing List One - One Name', email='list1-one-name@domain.com'), EmailAddress(name='Mailing List Two - Second Name', email='list2-second-name@domain.com')),
    reply_to_values=(),
)


"""

If you want to save message as .eml file, work with MailMessage.obj - it is email.message.EmailMessage

python email lib docs:

    https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.as_string
    https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.as_bytes

"""



import re
import sys
import datetime
from itertools import zip_longest
from email.utils import getaddresses, parsedate_to_datetime
from email.header import decode_header, Header
from typing import Union, Optional, Tuple, Iterable, Any, List, Dict, Iterator, Sequence

from .consts import SHORT_MONTH_NAMES, MailMessageFlags
from .imap_utf7 import utf7_encode

StrOrBytes = Union[str, bytes]


def clean_uids(uid_set: Union[str, Iterable[str]]) -> List[str]:
    """
    Prepare set of uid for use in IMAP commands
    uid RE patterns are not strict and allow invalid combinations, but simple. Example: 2,4:7,9,12:*
    :param uid_set:
        str, that is comma separated uids
        Iterable, that contains str uids
    :return: list of str - cleaned uids
    """
    # str
    if type(uid_set) is str:
        if re.search(r'^([\d*:]+,)*[\d*:]+$', uid_set):  # *optimization for already good str
            return uid_set.split(',')
        uid_set = uid_set.split(',')
    # check uid types
    for uid in uid_set:
        if type(uid) is not str:
            raise TypeError(f'uid "{str(uid)}" is not string')
        if not re.match(r'^[\d*:]+$', uid.strip()):
            raise TypeError(f'Wrong uid: "{uid}"')
    return [i.strip() for i in uid_set]


def check_command_status(command_result: tuple, exception: type, expected='OK'):
    """
    Check that IMAP command responses status equals <expected> status
    If not, raise specified <exception>
    :param command_result: imap command result: tuple(typ, data)
    :param exception: exception subclass of UnexpectedCommandStatusError, that raises
    :param expected: expected command status
    """
    typ, data = command_result[0], command_result[1]
    if typ != expected:
        raise exception(command_result=command_result, expected=expected)


def decode_value(value: StrOrBytes, encoding: Optional[str] = None) -> str:
    """Converts value to utf-8 encoding"""
    if isinstance(encoding, str):
        encoding = encoding.lower()
    if isinstance(value, bytes):
        try:
            return value.decode(encoding or 'utf-8', 'ignore')
        except LookupError:  # unknown encoding
            return value.decode('utf-8', 'ignore')
    return value


class EmailAddress:
    """Parsed email address info"""
    __slots__ = 'name', 'email'

    def __init__(self, name: str, email: str):
        self.name = name
        self.email = email

    @property
    def full(self):
        return f'{self.name} <{self.email}>' if self.name and self.email else self.name or self.email

    def __repr__(self):
        return f"{self.__class__.__name__}(name={repr(self.name)}, email={repr(self.email)})"

    def __eq__(self, other):
        return all(getattr(self, i) == getattr(other, i) for i in self.__slots__)


def remove_non_printable(value: str) -> str:
    """Remove non-printable character from value"""
    return ''.join(i for i in value if i.isprintable())


def parse_email_addresses(raw_header: Union[str, Header]) -> Tuple[EmailAddress, ...]:
    """
    Parse email addresses from header
    :param raw_header: example: '=?UTF-8?B?0J7Qu9C1=?= <name@company.ru>,\r\n "\'\\"z, z\\"\'" <imap.tools@ya.ru>'
    :return: (EmailAddress, ...)
    """
    result = []
    if type(raw_header) is Header:
        raw_header = decode_value(*decode_header(raw_header)[0])
    for raw_name, email in getaddresses([remove_non_printable(raw_header)]):
        name = decode_value(*decode_header(raw_name)[0]).strip()
        email = email.strip()
        if not (name or email):
            continue
        result.append(EmailAddress(
            name=name or (email if '@' not in email else ''),
            email=email if '@' in email else '',
        ))
    return tuple(result)


def parse_email_date(value: str) -> datetime.datetime:
    """
    Parsing the date described in rfc2822
    Result datetime may be naive or with tzinfo
    1900-1-1 for unparsed
    """
    try:
        return parsedate_to_datetime(value)
    except Exception:  # noqa
        pass
    match = re.search(
        r'(?P<date>\d{1,2}\s+(' + '|'.join(SHORT_MONTH_NAMES) + r')\s+\d{4})\s+' +
        r'(?P<time>\d{1,2}:\d{1,2}(:\d{1,2})?)\s*' +
        r'(?P<zone_sign>[+-])?(?P<zone>\d{4})?',
        value
    )
    if match:
        group = match.groupdict()
        day, month, year = group['date'].split()
        time_values = group['time'].split(':')
        zone_sign = int(f'{group.get("zone_sign") or "+"}1')
        zone = group['zone']
        try:
            return datetime.datetime(
                year=int(year),
                month=SHORT_MONTH_NAMES.index(month) + 1,
                day=int(day),
                hour=int(time_values[0]),
                minute=int(time_values[1]),
                second=int(time_values[2]) if len(time_values) > 2 else 0,
                tzinfo=datetime.timezone(datetime.timedelta(
                    hours=int(zone[:2]) * zone_sign,
                    minutes=int(zone[2:]) * zone_sign
                )) if zone else None,
            )
        except ValueError:
            pass
    return datetime.datetime(1900, 1, 1)


def quote(value: StrOrBytes) -> StrOrBytes:
    if isinstance(value, str):
        return '"' + value.replace('\\', '\\\\').replace('"', '\\"') + '"'
    else:
        return b'"' + value.replace(b'\\', b'\\\\').replace(b'"', b'\\"') + b'"'


def pairs_to_dict(items: List[Any]) -> Dict[Any, Any]:
    """Example: ['MESSAGES', '3', 'UIDNEXT', '4'] -> {'MESSAGES': '3', 'UIDNEXT': '4'}"""
    if len(items) % 2 != 0:
        raise ValueError('An even-length array is expected')
    return dict((items[i * 2], items[i * 2 + 1]) for i in range(len(items) // 2))


def encode_folder(folder: StrOrBytes) -> bytes:
    """Encode folder name"""
    if isinstance(folder, bytes):
        return folder
    else:
        return quote(utf7_encode(folder))


def clean_flags(flag_set: Union[str, Iterable[str]]) -> List[str]:
    """
    Check the correctness of the flags
    :return: list of str - flags
    """
    if type(flag_set) is str:
        flag_set = [flag_set]
    upper_sys_flags = tuple(i.upper() for i in MailMessageFlags.all)
    for flag in flag_set:
        if not type(flag) is str:
            raise ValueError(f'Flag - str value expected, but {type(flag_set)} received')
        if flag.upper() not in upper_sys_flags and flag.startswith('\\'):
            raise ValueError('Non system flag must not start with "\\"')
    return flag_set


def check_timeout_arg_support(timeout):
    """If timeout arg not supports - raise ValueError"""
    if timeout is not None and sys.version_info.minor < 9:
        raise ValueError('imaplib.IMAP4 timeout argument supported since python 3.9')


def replace_html_ct_charset(html: str, new_charset: str) -> str:
    """Replace charset in META tag with content-type attribute in HTML text"""
    meta_ct_match = re.search(r'<\s*meta .*?content-type.*?>', html, re.IGNORECASE | re.DOTALL)
    if meta_ct_match:
        meta = meta_ct_match.group(0)
        meta_new = re.sub(
            pattern=r'charset\s*=\s*[a-zA-Z0-9_:.+-]+',
            repl=f'charset={new_charset}',
            string=meta,
            count=1,
            flags=re.IGNORECASE
        )
        html = html.replace(meta, meta_new)
    return html


def chunked(iterable: Iterable[Any], n: int, fill_value: Optional[Any] = None) -> Iterator[Tuple[Any, ...]]:
    """
    Group data into fixed-length chunks or blocks
        [iter(iterable)]*n creates one iterator, repeated n times in the list
        izip_longest then effectively performs a round-robin of "each" (same) iterator
    Examples:
        chunked('ABCDEFGH', 3, '?') --> [('A', 'B', 'C'), ('D', 'E', 'F'), ('G', 'H', '?')]
        chunked([1, 2, 3, 4, 5], 2) --> [(1, 2), (3, 4), (5, None)]
    """
    return zip_longest(*[iter(iterable)] * n, fillvalue=fill_value)


def chunked_crop(seq: Sequence, chunk_size: Optional[int]) -> Iterator[list]:
    """
    Yield successive n-sized chunks from seq.
    Yield seq if chunk_size is False-like
    :param seq: Sequence to chunks
    :param chunk_size: chunk size
    :return: Iterator
    import pprint
    pprint.pprint(list(chunked_crop(range(10, 75), 10)))
    [[10, 11, 12, 13, 14, 15, 16, 17, 18, 19],
     [20, 21, 22, 23, 24, 25, 26, 27, 28, 29],
     [30, 31, 32, 33, 34, 35, 36, 37, 38, 39],
     [40, 41, 42, 43, 44, 45, 46, 47, 48, 49],
     [50, 51, 52, 53, 54, 55, 56, 57, 58, 59],
     [60, 61, 62, 63, 64, 65, 66, 67, 68, 69],
     [70, 71, 72, 73, 74]]
    """
    if not chunk_size:
        yield seq
        return
    if chunk_size < 0:
        raise ValueError('False-like or int>=0 expected')
    for i in range(0, len(seq), chunk_size):
        yield seq[i:i + chunk_size]



import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='/home/svn/public/minebox revision 214',
    from_='tim@powerupdev.comconcierge',
    to=('tim@powerupdev.comconcierge', '@powerupdev.com'),
    cc=(),
    bcc=(),
    reply_to=('tim@powerupdev.comconcierge', '@powerupdev.com'),
    date=datetime.datetime(2007, 10, 22, 23, 45, 23, tzinfo=datetime.timezone.utc),
    date_str='Mon, 22 Oct 2007 23:45:23 +0000 (UTC)',
    text='<p><b>recordkick</b> 2007-10-22 23:45:23 +0000 (Mon, 22 Oct 2007)</p><p>test\r\nsubversion<br>\r\n</p><hr noshade><pre><font color=\\"gray\\">Modified:\r\ntrunk/README\r\n===================================================================\r\n--- trunk/README\\t2007-10-22\r\n23:41:34 UTC (rev 213)\r\n+++ trunk/README\\t2007-10-22 23:45:23 UTC (rev 214)\r\n@@ -1,5 +1,5 @@\r\n == Welcome\r\nto Rails\r\n-Test\r\n+Tedst\r\n Rails is a web-application and persistence framework that includes everything\r\n needed\r\nto create database-backed web-applications according to the\r\n Model-View-Control pattern of separation. This pattern\r\nsplits the view (also\r\n\r\n</font>\r\n</pre>\r\n',
    html='',
    headers={'delivered-to': ('tim@powerupdev.com',), 'return-path': ('<www-data@mangaverde.net>',), 'to': ('tim@powerupdev.com concierge@powerupdev.com',), 'from': ('tim@powerupdev.com concierge@powerupdev.com',), 'subject': ('/home/svn/public/minebox revision 214',), 'reply-to': ('tim@powerupdev.com concierge@powerupdev.com',), 'message-id': ('<20071022234523.5BD8E86D2@mangaverde.net>',), 'date': ('Mon, 22 Oct 2007 23:45:23 +0000 (UTC)',)},
    attachments=[],
    from_values=EmailAddress('', 'tim@powerupdev.comconcierge', 'tim@powerupdev.comconcierge'),
    to_values=(EmailAddress('', 'tim@powerupdev.comconcierge', 'tim@powerupdev.comconcierge'), EmailAddress('', '@powerupdev.com', '@powerupdev.com')),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(EmailAddress('', 'tim@powerupdev.comconcierge', 'tim@powerupdev.comconcierge'), EmailAddress('', '@powerupdev.com', '@powerupdev.com')),
)


from imap_tools import MailBox

# Authenticate to account using OAuth 2.0 mechanism
with MailBox('imap.my.ru').xoauth2('user', 'token123', 'INBOX') as mailbox:
    for msg in mailbox.fetch():
        print(msg.date_str, msg.subject)



"""

If you want to use really secure connection, you MUST read this articles:

https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4_SSL
https://docs.python.org/3/library/ssl.html#ssl-security

"""

import ssl

from imap_tools import MailBoxTls

ssl_context = ssl.create_default_context()
ssl_context.load_cert_chain(certfile="./one.crt", keyfile="./one.key")
with MailBoxTls('imap.my.ru', ssl_context=ssl_context).login('acc', 'pwd', 'INBOX') as mailbox:
    for msg in mailbox.fetch():
        print(msg.subject, msg.date_str)



import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Impress your clients with a business phone��� ',
    from_='info@here2there-travelers-msgs.net',
    to=('anyone@YAHOO.COM',),
    cc=(),
    bcc=(),
    reply_to=('44.41.17.14.11.2010.1139.1.328.1477949.614@reply.here2there-travelers-msgs.net',),
    date=datetime.datetime(2010, 11, 14, 17, 41, 44, tzinfo=datetime.timezone.utc),
    date_str='Sun, 14 Nov 2010 17:41:44 +0000',
    text='',
    html='',
    headers={'x-ymail-umid': ('1_132725_AEe3iGIAAGS4TOAfWQ3foSiBC54',), 'x-apparently-to': ('anyone@yahoo.com via 98.136.183.71; Sun, 14 Nov 2010 09:41:45 -0800',), 'message-id': ('<201011141741.oAEHfiKs020181@app9.msg2u.net>',), 'mime-version': ('1.0',), 'content-transfer-encoding': ('binary',), 'content-type': ('multipart/alternative; boundary="_----------=_128975650412616235"',), 'x-mailer': ('MIME::Lite 3.020 (F2.73; T1.21; A1.77; B3.01; Q3.01)',), 'date': ('Sun, 14 Nov 2010 17:41:44 +0000',), 'from': ('Biz Phone Systems from EclipseMediaOnline\udcef\udcbf\udcbd\udcef\udcbf\udcbd  <info@here2there-travelers-msgs.net>',), 'to': ('anyone@YAHOO.COM',), 'subject': ('Impress your clients with a business phone\udcef\udcbf\udcbd\udcef\udcbf\udcbd\udcef\udcbf\udcbd ',), 'reply-to': ('Biz Phone Systems from EclipseMediaOnline\udcef\udcbf\udcbd\udcef\udcbf\udcbd  <44.41.17.14.11.2010.1139.1.328.1477949.614@reply.here2there-travelers-msgs.net>',)},
    attachments=[],
    from_values=EmailAddress(name='Biz Phone Systems from EclipseMediaOnline��', email='info@here2there-travelers-msgs.net'),
    to_values=(EmailAddress(name='', email='anyone@YAHOO.COM'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(EmailAddress(name='Biz Phone Systems from EclipseMediaOnline��', email='44.41.17.14.11.2010.1139.1.328.1477949.614@reply.here2there-travelers-msgs.net'),),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Redacted',
    from_='redacted@flashmail.net',
    to=('redacted@Enron.com',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(1900, 1, 1, 0, 0),
    date_str='',
    text='foo\n',
    html='<p>foo</p>\n',
    headers={'from': ('<redacted@flashmail.net>',), 'subject': ('Redacted',), 'to': ('<redacted@Enron.com>',), 'message-id': ('<105647271315.NCV17523@x263.net>',), 'mime-version': ('1.0',), 'content-type': ('multipart/alternative; boundary="----_001_5973_47T00ZN9.15SY2428"',), 'references': ('<foo@bar.net>', '<baz@bar.net>, <invalid.   ')},
    attachments=[],
    from_values=EmailAddress(name='', email='redacted@flashmail.net'),
    to_values=(EmailAddress(name='', email='redacted@Enron.com'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='testing',
    from_='raasdnil@gmail.com',
    to=('raasdnil@gmail.com',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(2009, 10, 16, 23, 39, 34, tzinfo=datetime.timezone(datetime.timedelta(seconds=39600))),
    date_str='Fri, 16 Oct 2009 23:39:34 +1100',
    text='testing\r\n\r\n-- \r\nhttp://lindsaar.net/\r\nRails, RSpec and Life blog....\r\n',
    html='',
    headers={'mime-version': ('1.0',), 'received': ('by 10.231.35.72 with HTTP; Fri, 16 Oct 2009 05:39:34 -0700 (PDT)',), 'date': ('Fri, 16 Oct 2009 23:39:34 +1100',), 'delivered-to': ('raasdnil@gmail.com',), 'message-id': ('<57a815bf0910160539m64240421gb35ea52e101aedbc@mail.gmail.com>',), 'subject': ('testing',), 'from': ('Mikel Lindsaar <raasdnil@gmail.com>',), 'to': ('Mikel Lindsaar <raasdnil@gmail.com>',), 'content-type': ('multipart/mixed; boundary=00032557395e3572cf04760cb060',)},
    attachments=[
        dict(
            filename='てすと.txt',
            content_id='',
            content_disposition='attachment',
            content_type='text/plain',
            payload=b'this is a test\n\xe3\x81\x93\xe3\x82\x8c\xe3\x82\x8f\xe3\x81\xa6\xe3\x81\x99\xe3\x81\xa8',
        ),
        ],
    from_values=EmailAddress(name='Mikel Lindsaar', email='raasdnil@gmail.com'),
    to_values=(EmailAddress(name='Mikel Lindsaar', email='raasdnil@gmail.com'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Undelivered Mail Returned to Sender',
    from_='MAILER-DAEMON@lvmail01.LL.com',
    to=('rahul.chaudhari@LL.com',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(2010, 2, 23, 22, 16, 41, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=57600))),
    date_str='Tue, 23 Feb 2010 22:16:41 -0800 (PST)',
    text="This is the mail system at host lvmail01.LL.com.\r\n\r\nI'm sorry to have to inform you that your message could not\r\nbe delivered to one or more recipients. It's attached below.\r\n\r\nFor further assistance, please send mail to postmaster.\r\n\r\nIf you do so, please include this problem report. You can\r\ndelete your own text from the attached returned message.\r\n\r\n                   The mail system\r\n\r\n<bbbbvhvbbvkjbhfbvbvjhb@gmail.com>: host\r\n    gmail-smtp-in.l.google.com[209.85.223.33] said: 550-5.1.1 The email account\r\n    that you tried to reach does not exist. Please try 550-5.1.1\r\n    double-checking the recipient's email address for typos or 550-5.1.1\r\n    unnecessary spaces. Learn more at                              550 5.1.1\r\n    http://mail.google.com/support/bin/answer.py?answer=6596 41si5422799iwn.27\r\n    (in reply to RCPT TO command)\r\n\r\n<bscdbcjhasbcjhbdscbhbsdhcbj@gmail.com>: host\r\n    gmail-smtp-in.l.google.com[209.85.223.33] said: 550-5.1.1 The email account\r\n    that you tried to reach does not exist. Please try 550-5.1.1\r\n    double-checking the recipient's email address for typos or 550-5.1.1\r\n    unnecessary spaces. Learn more at                              550 5.1.1\r\n    http://mail.google.com/support/bin/answer.py?answer=6596 41si5422799iwn.27\r\n    (in reply to RCPT TO command)\r\n\r\n<egyfefsdvsfvvhjsd@gmail.com>: host gmail-smtp-in.l.google.com[209.85.223.33]\r\n    said: 550-5.1.1 The email account that you tried to reach does not exist.\r\n    Please try 550-5.1.1 double-checking the recipient's email address for\r\n    typos or 550-5.1.1 unnecessary spaces. Learn more at\r\n    550 5.1.1 http://mail.google.com/support/bin/answer.py?answer=6596\r\n    41si5422799iwn.27 (in reply to RCPT TO command)\r\n\r\n<kfhejkfbsjkjsbhds@gmail.com>: host gmail-smtp-in.l.google.com[209.85.223.33]\r\n    said: 550-5.1.1 The email account that you tried to reach does not exist.\r\n    Please try 550-5.1.1 double-checking the recipient's email address for\r\n    typos or 550-5.1.1 unnecessary spaces. Learn more at\r\n    550 5.1.1 http://mail.google.com/support/bin/answer.py?answer=6596\r\n    41si5422799iwn.27 (in reply to RCPT TO command)\r\n\r\n<qfvhgsvhgsduiohncdhcvhsdfvsfygusd@gmail.com>: host\r\n    gmail-smtp-in.l.google.com[209.85.223.33] said: 550-5.1.1 The email account\r\n    that you tried to reach does not exist. Please try 550-5.1.1\r\n    double-checking the recipient's email address for typos or 550-5.1.1\r\n    unnecessary spaces. Learn more at                              550 5.1.1\r\n    http://mail.google.com/support/bin/answer.py?answer=6596 41si5422799iwn.27\r\n    (in reply to RCPT TO command)\r\nThis is just testing.\r\n\r\n\r\nThanks & Regards,\r\nRahul P. Chaudhari\r\nSoftware Developer\r\nLIVIA India Private Limited\r\n\r\nBoard Line - +91.22.6725 5100\r\nHand Phone - +91.809 783 3437\r\nWeb URL: www.LL.com \r\n",
    html='',
    headers={'received': ('from lvmail01.LL.com (LHLO lvmail01.LL.com)\r\n (10.60.6.3) by lvmail01.LL.com with LMTP; Tue, 23 Feb 2010 22:16:41\r\n -0800 (PST)', 'by lvmail01.LL.com (Postfix)\r\n\tid 3E47A1BC025; Tue, 23 Feb 2010 22:16:41 -0800 (PST)'), 'date': ('Tue, 23 Feb 2010 22:16:41 -0800 (PST)',), 'from': ('MAILER-DAEMON@lvmail01.LL.com (Mail Delivery System)',), 'subject': ('Undelivered Mail Returned to Sender',), 'to': ('rahul.chaudhari@LL.com',), 'auto-submitted': ('auto-replied',), 'mime-version': ('1.0',), 'content-type': ('multipart/report; report-type=delivery-status;\r\n\tboundary="9B7841BC027.1266992201/lvmail01.LL.com"',), 'content-transfer-encoding': ('7bit',), 'message-id': ('<20100224061641.3E47A1BC025@lvmail01.LL.com>',)},
    attachments=[
        dict(
            filename='',
            content_id='',
            content_disposition='',
            content_type='message/rfc822',
            payload=b'Return-Path: <rahul.chaudhari@LL.com>\nReceived: from localhost (localhost [127.0.0.1])\n\tby lvmail01.LL.com (Postfix) with ESMTP id 9B7841BC027;\n\tTue, 23 Feb 2010 22:16:15 -0800 (PST)\nX-Virus-Scanned: amavisd-new at LL.com\nReceived: from lvmail01.LL.com ([127.0.0.1])\n\tby localhost (lvmail01.LL.com [127.0.0.1]) (amavisd-new, port 10024)\n\twith ESMTP id HXMOLJWXGcFK; Tue, 23 Feb 2010 22:16:15 -0800 (PST)\nReceived: from lvmail01.LL.com (lvmail01.LL.com [10.60.6.3])\n\tby lvmail01.LL.com (Postfix) with ESMTP id 12D311BC025;\n\tTue, 23 Feb 2010 22:16:15 -0800 (PST)\nDate: Tue, 23 Feb 2010 22:16:14 -0800 (PST)\nFrom: Rahul Chaudhari <rahul.chaudhari@LL.com>\nTo: egyfefsdvsfvvhjsd@gmail.com, kfhejkfbsjkjsbhds@gmail.com,\n\tbbbbvhvbbvkjbhfbvbvjhb@gmail.com,\n\tqfvhgsvhgsduiohncdhcvhsdfvsfygusd@gmail.com,\n\tbscdbcjhasbcjhbdscbhbsdhcbj@gmail.com\nMessage-ID: <118707422.15521266992174819.JavaMail.root@lvmail01>\nSubject: Test of bounce email\nMIME-Version: 1.0\nContent-Type: text/plain; charset=utf-8\nContent-Transfer-Encoding: 7bit\nX-Originating-IP: [10.50.4.44]\nX-Mailer: Zimbra 6.0.1_GA_1816.UBUNTU8_64 (ZimbraWebClient - FF3.0\n (Linux)/6.0.1_GA_1816.UBUNTU8_64)\n\nThis is just testing.\n\n\nThanks & Regards,\nRahul P. Chaudhari\nSoftware Developer\nLIVIA India Private Limited\n\nBoard Line - +91.22.6725 5100\nHand Phone - +91.809 783 3437\nWeb URL: www.LL.com \n',
        ),
        ],
    from_values=EmailAddress(name='Mail Delivery System', email='MAILER-DAEMON@lvmail01.LL.com'),
    to_values=(EmailAddress(name='', email='rahul.chaudhari@LL.com'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)